import typing

import android.accounts
import android.app
import android.content
import android.content.pm
import android.content.res
import android.database
import android.graphics
import android.graphics.fonts
import android.net
import android.os
import android.telephony
import android.util
import android.view
import java
import java.chaquopy
import java.io
import java.lang
import java.util

class AlarmClock(java.lang.Object):
    ACTION_DISMISS_ALARM: typing.ClassVar[str] = ...
    ACTION_DISMISS_TIMER: typing.ClassVar[str] = ...
    ACTION_SET_ALARM: typing.ClassVar[str] = ...
    ACTION_SET_TIMER: typing.ClassVar[str] = ...
    ACTION_SHOW_ALARMS: typing.ClassVar[str] = ...
    ACTION_SHOW_TIMERS: typing.ClassVar[str] = ...
    ACTION_SNOOZE_ALARM: typing.ClassVar[str] = ...
    ALARM_SEARCH_MODE_ALL: typing.ClassVar[str] = ...
    ALARM_SEARCH_MODE_LABEL: typing.ClassVar[str] = ...
    ALARM_SEARCH_MODE_NEXT: typing.ClassVar[str] = ...
    ALARM_SEARCH_MODE_TIME: typing.ClassVar[str] = ...
    EXTRA_ALARM_SEARCH_MODE: typing.ClassVar[str] = ...
    EXTRA_ALARM_SNOOZE_DURATION: typing.ClassVar[str] = ...
    EXTRA_DAYS: typing.ClassVar[str] = ...
    EXTRA_HOUR: typing.ClassVar[str] = ...
    EXTRA_IS_PM: typing.ClassVar[str] = ...
    EXTRA_LENGTH: typing.ClassVar[str] = ...
    EXTRA_MESSAGE: typing.ClassVar[str] = ...
    EXTRA_MINUTES: typing.ClassVar[str] = ...
    EXTRA_RINGTONE: typing.ClassVar[str] = ...
    EXTRA_SKIP_UI: typing.ClassVar[str] = ...
    EXTRA_VIBRATE: typing.ClassVar[str] = ...
    VALUE_RINGTONE_SILENT: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...

class BaseColumns(java.lang.Object):
    _COUNT: typing.ClassVar[str] = ...
    _ID: typing.ClassVar[str] = ...

class BlockedNumberContract(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    AUTHORITY_URI: typing.ClassVar[android.net.Uri] = ...
    @staticmethod
    def canCurrentUserBlockNumbers(context: android.content.Context, /) -> bool: ...
    @staticmethod
    def isBlocked(context: android.content.Context, phoneNumber: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def unblock(context: android.content.Context, phoneNumber: str | java.lang.String, /) -> int: ...

    class BlockedNumbers(java.lang.Object):
        COLUMN_E164_NUMBER: typing.ClassVar[str] = ...
        COLUMN_ID: typing.ClassVar[str] = ...
        COLUMN_ORIGINAL_NUMBER: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

class Browser(java.lang.Object):
    EXTRA_APPLICATION_ID: typing.ClassVar[str] = ...
    EXTRA_CREATE_NEW_TAB: typing.ClassVar[str] = ...
    EXTRA_HEADERS: typing.ClassVar[str] = ...
    INITIAL_ZOOM_LEVEL: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def sendString(context: android.content.Context, string: str | java.lang.String, /) -> None: ...

class CalendarContract(java.lang.Object):
    ACCOUNT_TYPE_LOCAL: typing.ClassVar[str] = ...
    ACTION_EVENT_REMINDER: typing.ClassVar[str] = ...
    ACTION_HANDLE_CUSTOM_EVENT: typing.ClassVar[str] = ...
    ACTION_VIEW_MANAGED_PROFILE_CALENDAR_EVENT: typing.ClassVar[str] = ...
    AUTHORITY: typing.ClassVar[str] = ...
    CALLER_IS_SYNCADAPTER: typing.ClassVar[str] = ...
    CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
    EXTRA_CUSTOM_APP_URI: typing.ClassVar[str] = ...
    EXTRA_EVENT_ALL_DAY: typing.ClassVar[str] = ...
    EXTRA_EVENT_BEGIN_TIME: typing.ClassVar[str] = ...
    EXTRA_EVENT_END_TIME: typing.ClassVar[str] = ...
    EXTRA_EVENT_ID: typing.ClassVar[str] = ...
    @staticmethod
    def startViewCalendarEventInManagedProfile(context: android.content.Context, eventId: int | java.jlong | java.lang.Long, startMs: int | java.jlong | java.lang.Long, endMs: int | java.jlong | java.lang.Long, allDay: bool | java.jboolean | java.lang.Boolean, flags: int | java.jint | java.lang.Integer, /) -> bool: ...

    class SyncState(SyncStateContract.Columns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

    class SyncColumns(CalendarContract.CalendarSyncColumns):
        ACCOUNT_NAME: typing.ClassVar[str] = ...
        ACCOUNT_TYPE: typing.ClassVar[str] = ...
        CAN_PARTIALLY_UPDATE: typing.ClassVar[str] = ...
        DELETED: typing.ClassVar[str] = ...
        DIRTY: typing.ClassVar[str] = ...
        MUTATORS: typing.ClassVar[str] = ...
        _SYNC_ID: typing.ClassVar[str] = ...

    class RemindersColumns(java.lang.Object):
        EVENT_ID: typing.ClassVar[str] = ...
        METHOD: typing.ClassVar[str] = ...
        METHOD_ALARM: typing.ClassVar[int] = ...
        METHOD_ALERT: typing.ClassVar[int] = ...
        METHOD_DEFAULT: typing.ClassVar[int] = ...
        METHOD_EMAIL: typing.ClassVar[int] = ...
        METHOD_SMS: typing.ClassVar[int] = ...
        MINUTES: typing.ClassVar[str] = ...
        MINUTES_DEFAULT: typing.ClassVar[int] = ...

    class Reminders(BaseColumns, CalendarContract.EventsColumns, CalendarContract.RemindersColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def query(cr: android.content.ContentResolver, eventId: int | java.jlong | java.lang.Long, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...

    class Instances(BaseColumns, CalendarContract.CalendarColumns, CalendarContract.EventsColumns):
        BEGIN: typing.ClassVar[str] = ...
        CONTENT_BY_DAY_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_SEARCH_BY_DAY_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_SEARCH_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        END: typing.ClassVar[str] = ...
        END_DAY: typing.ClassVar[str] = ...
        END_MINUTE: typing.ClassVar[str] = ...
        ENTERPRISE_CONTENT_BY_DAY_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_SEARCH_BY_DAY_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_SEARCH_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        EVENT_ID: typing.ClassVar[str] = ...
        START_DAY: typing.ClassVar[str] = ...
        START_MINUTE: typing.ClassVar[str] = ...
        @typing.overload
        @staticmethod
        def query(cr: android.content.ContentResolver, projection: java.chaquopy.JavaArray[java.lang.String], begin: int | java.jlong | java.lang.Long, end: int | java.jlong | java.lang.Long, /) -> android.database.Cursor: ...
        @typing.overload
        @staticmethod
        def query(cr: android.content.ContentResolver, projection: java.chaquopy.JavaArray[java.lang.String], begin: int | java.jlong | java.lang.Long, end: int | java.jlong | java.lang.Long, searchQuery: str | java.lang.String, /) -> android.database.Cursor: ...

    class ExtendedPropertiesColumns(java.lang.Object):
        EVENT_ID: typing.ClassVar[str] = ...
        NAME: typing.ClassVar[str] = ...
        VALUE: typing.ClassVar[str] = ...

    class ExtendedProperties(BaseColumns, CalendarContract.EventsColumns, CalendarContract.ExtendedPropertiesColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

    class EventsEntity(BaseColumns, CalendarContract.EventsColumns, CalendarContract.SyncColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @typing.overload
        @staticmethod
        def newEntityIterator(cursor: android.database.Cursor, provider: android.content.ContentProviderClient, /) -> android.content.EntityIterator: ...
        @typing.overload
        @staticmethod
        def newEntityIterator(cursor: android.database.Cursor, resolver: android.content.ContentResolver, /) -> android.content.EntityIterator: ...

    class EventsColumns(java.lang.Object):
        ACCESS_CONFIDENTIAL: typing.ClassVar[int] = ...
        ACCESS_DEFAULT: typing.ClassVar[int] = ...
        ACCESS_LEVEL: typing.ClassVar[str] = ...
        ACCESS_PRIVATE: typing.ClassVar[int] = ...
        ACCESS_PUBLIC: typing.ClassVar[int] = ...
        ALL_DAY: typing.ClassVar[str] = ...
        AVAILABILITY: typing.ClassVar[str] = ...
        AVAILABILITY_BUSY: typing.ClassVar[int] = ...
        AVAILABILITY_FREE: typing.ClassVar[int] = ...
        AVAILABILITY_TENTATIVE: typing.ClassVar[int] = ...
        CALENDAR_ID: typing.ClassVar[str] = ...
        CAN_INVITE_OTHERS: typing.ClassVar[str] = ...
        CUSTOM_APP_PACKAGE: typing.ClassVar[str] = ...
        CUSTOM_APP_URI: typing.ClassVar[str] = ...
        DESCRIPTION: typing.ClassVar[str] = ...
        DISPLAY_COLOR: typing.ClassVar[str] = ...
        DTEND: typing.ClassVar[str] = ...
        DTSTART: typing.ClassVar[str] = ...
        DURATION: typing.ClassVar[str] = ...
        EVENT_COLOR: typing.ClassVar[str] = ...
        EVENT_COLOR_KEY: typing.ClassVar[str] = ...
        EVENT_END_TIMEZONE: typing.ClassVar[str] = ...
        EVENT_LOCATION: typing.ClassVar[str] = ...
        EVENT_TIMEZONE: typing.ClassVar[str] = ...
        EXDATE: typing.ClassVar[str] = ...
        EXRULE: typing.ClassVar[str] = ...
        GUESTS_CAN_INVITE_OTHERS: typing.ClassVar[str] = ...
        GUESTS_CAN_MODIFY: typing.ClassVar[str] = ...
        GUESTS_CAN_SEE_GUESTS: typing.ClassVar[str] = ...
        HAS_ALARM: typing.ClassVar[str] = ...
        HAS_ATTENDEE_DATA: typing.ClassVar[str] = ...
        HAS_EXTENDED_PROPERTIES: typing.ClassVar[str] = ...
        IS_ORGANIZER: typing.ClassVar[str] = ...
        LAST_DATE: typing.ClassVar[str] = ...
        LAST_SYNCED: typing.ClassVar[str] = ...
        ORGANIZER: typing.ClassVar[str] = ...
        ORIGINAL_ALL_DAY: typing.ClassVar[str] = ...
        ORIGINAL_ID: typing.ClassVar[str] = ...
        ORIGINAL_INSTANCE_TIME: typing.ClassVar[str] = ...
        ORIGINAL_SYNC_ID: typing.ClassVar[str] = ...
        RDATE: typing.ClassVar[str] = ...
        RRULE: typing.ClassVar[str] = ...
        SELF_ATTENDEE_STATUS: typing.ClassVar[str] = ...
        STATUS: typing.ClassVar[str] = ...
        STATUS_CANCELED: typing.ClassVar[int] = ...
        STATUS_CONFIRMED: typing.ClassVar[int] = ...
        STATUS_TENTATIVE: typing.ClassVar[int] = ...
        SYNC_DATA10: typing.ClassVar[str] = ...
        SYNC_DATA1: typing.ClassVar[str] = ...
        SYNC_DATA2: typing.ClassVar[str] = ...
        SYNC_DATA3: typing.ClassVar[str] = ...
        SYNC_DATA4: typing.ClassVar[str] = ...
        SYNC_DATA5: typing.ClassVar[str] = ...
        SYNC_DATA6: typing.ClassVar[str] = ...
        SYNC_DATA7: typing.ClassVar[str] = ...
        SYNC_DATA8: typing.ClassVar[str] = ...
        SYNC_DATA9: typing.ClassVar[str] = ...
        TITLE: typing.ClassVar[str] = ...
        UID_2445: typing.ClassVar[str] = ...

    class Events(BaseColumns, CalendarContract.CalendarColumns, CalendarContract.EventsColumns, CalendarContract.SyncColumns):
        CONTENT_EXCEPTION_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

    class EventDaysColumns(java.lang.Object):
        ENDDAY: typing.ClassVar[str] = ...
        STARTDAY: typing.ClassVar[str] = ...

    class EventDays(CalendarContract.EventDaysColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def query(cr: android.content.ContentResolver, startDay: int | java.jint | java.lang.Integer, numDays: int | java.jint | java.lang.Integer, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...

    class ColorsColumns(SyncStateContract.Columns):
        COLOR: typing.ClassVar[str] = ...
        COLOR_KEY: typing.ClassVar[str] = ...
        COLOR_TYPE: typing.ClassVar[str] = ...
        TYPE_CALENDAR: typing.ClassVar[int] = ...
        TYPE_EVENT: typing.ClassVar[int] = ...

    class Colors(CalendarContract.ColorsColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

    class Calendars(BaseColumns, CalendarContract.CalendarColumns, CalendarContract.SyncColumns):
        CALENDAR_LOCATION: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        ENTERPRISE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        NAME: typing.ClassVar[str] = ...

    class CalendarSyncColumns(java.lang.Object):
        CAL_SYNC10: typing.ClassVar[str] = ...
        CAL_SYNC1: typing.ClassVar[str] = ...
        CAL_SYNC2: typing.ClassVar[str] = ...
        CAL_SYNC3: typing.ClassVar[str] = ...
        CAL_SYNC4: typing.ClassVar[str] = ...
        CAL_SYNC5: typing.ClassVar[str] = ...
        CAL_SYNC6: typing.ClassVar[str] = ...
        CAL_SYNC7: typing.ClassVar[str] = ...
        CAL_SYNC8: typing.ClassVar[str] = ...
        CAL_SYNC9: typing.ClassVar[str] = ...

    class CalendarEntity(BaseColumns, CalendarContract.CalendarColumns, CalendarContract.SyncColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def newEntityIterator(cursor: android.database.Cursor, /) -> android.content.EntityIterator: ...

    class CalendarColumns(java.lang.Object):
        ALLOWED_ATTENDEE_TYPES: typing.ClassVar[str] = ...
        ALLOWED_AVAILABILITY: typing.ClassVar[str] = ...
        ALLOWED_REMINDERS: typing.ClassVar[str] = ...
        CALENDAR_ACCESS_LEVEL: typing.ClassVar[str] = ...
        CALENDAR_COLOR: typing.ClassVar[str] = ...
        CALENDAR_COLOR_KEY: typing.ClassVar[str] = ...
        CALENDAR_DISPLAY_NAME: typing.ClassVar[str] = ...
        CALENDAR_TIME_ZONE: typing.ClassVar[str] = ...
        CAL_ACCESS_CONTRIBUTOR: typing.ClassVar[int] = ...
        CAL_ACCESS_EDITOR: typing.ClassVar[int] = ...
        CAL_ACCESS_FREEBUSY: typing.ClassVar[int] = ...
        CAL_ACCESS_NONE: typing.ClassVar[int] = ...
        CAL_ACCESS_OVERRIDE: typing.ClassVar[int] = ...
        CAL_ACCESS_OWNER: typing.ClassVar[int] = ...
        CAL_ACCESS_READ: typing.ClassVar[int] = ...
        CAL_ACCESS_RESPOND: typing.ClassVar[int] = ...
        CAL_ACCESS_ROOT: typing.ClassVar[int] = ...
        CAN_MODIFY_TIME_ZONE: typing.ClassVar[str] = ...
        CAN_ORGANIZER_RESPOND: typing.ClassVar[str] = ...
        IS_PRIMARY: typing.ClassVar[str] = ...
        MAX_REMINDERS: typing.ClassVar[str] = ...
        OWNER_ACCOUNT: typing.ClassVar[str] = ...
        SYNC_EVENTS: typing.ClassVar[str] = ...
        VISIBLE: typing.ClassVar[str] = ...

    class CalendarCacheColumns(java.lang.Object):
        KEY: typing.ClassVar[str] = ...
        VALUE: typing.ClassVar[str] = ...

    class CalendarCache(CalendarContract.CalendarCacheColumns):
        KEY_TIMEZONE_INSTANCES: typing.ClassVar[str] = ...
        KEY_TIMEZONE_INSTANCES_PREVIOUS: typing.ClassVar[str] = ...
        KEY_TIMEZONE_TYPE: typing.ClassVar[str] = ...
        TIMEZONE_TYPE_AUTO: typing.ClassVar[str] = ...
        TIMEZONE_TYPE_HOME: typing.ClassVar[str] = ...
        URI: typing.ClassVar[android.net.Uri] = ...

    class CalendarAlertsColumns(java.lang.Object):
        ALARM_TIME: typing.ClassVar[str] = ...
        BEGIN: typing.ClassVar[str] = ...
        CREATION_TIME: typing.ClassVar[str] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        END: typing.ClassVar[str] = ...
        EVENT_ID: typing.ClassVar[str] = ...
        MINUTES: typing.ClassVar[str] = ...
        NOTIFY_TIME: typing.ClassVar[str] = ...
        RECEIVED_TIME: typing.ClassVar[str] = ...
        STATE: typing.ClassVar[str] = ...
        STATE_DISMISSED: typing.ClassVar[int] = ...
        STATE_FIRED: typing.ClassVar[int] = ...
        STATE_SCHEDULED: typing.ClassVar[int] = ...

    class CalendarAlerts(BaseColumns, CalendarContract.CalendarAlertsColumns, CalendarContract.CalendarColumns, CalendarContract.EventsColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI_BY_INSTANCE: typing.ClassVar[android.net.Uri] = ...

    class AttendeesColumns(java.lang.Object):
        ATTENDEE_EMAIL: typing.ClassVar[str] = ...
        ATTENDEE_IDENTITY: typing.ClassVar[str] = ...
        ATTENDEE_ID_NAMESPACE: typing.ClassVar[str] = ...
        ATTENDEE_NAME: typing.ClassVar[str] = ...
        ATTENDEE_RELATIONSHIP: typing.ClassVar[str] = ...
        ATTENDEE_STATUS: typing.ClassVar[str] = ...
        ATTENDEE_STATUS_ACCEPTED: typing.ClassVar[int] = ...
        ATTENDEE_STATUS_DECLINED: typing.ClassVar[int] = ...
        ATTENDEE_STATUS_INVITED: typing.ClassVar[int] = ...
        ATTENDEE_STATUS_NONE: typing.ClassVar[int] = ...
        ATTENDEE_STATUS_TENTATIVE: typing.ClassVar[int] = ...
        ATTENDEE_TYPE: typing.ClassVar[str] = ...
        EVENT_ID: typing.ClassVar[str] = ...
        RELATIONSHIP_ATTENDEE: typing.ClassVar[int] = ...
        RELATIONSHIP_NONE: typing.ClassVar[int] = ...
        RELATIONSHIP_ORGANIZER: typing.ClassVar[int] = ...
        RELATIONSHIP_PERFORMER: typing.ClassVar[int] = ...
        RELATIONSHIP_SPEAKER: typing.ClassVar[int] = ...
        TYPE_NONE: typing.ClassVar[int] = ...
        TYPE_OPTIONAL: typing.ClassVar[int] = ...
        TYPE_REQUIRED: typing.ClassVar[int] = ...
        TYPE_RESOURCE: typing.ClassVar[int] = ...

    class Attendees(BaseColumns, CalendarContract.AttendeesColumns, CalendarContract.EventsColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def query(cr: android.content.ContentResolver, eventId: int | java.jlong | java.lang.Long, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...

class CallLog(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
    def __init__(self) -> None: ...

    class Locations(BaseColumns):
        AUTHORITY: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        LATITUDE: typing.ClassVar[str] = ...
        LONGITUDE: typing.ClassVar[str] = ...

    class Calls(BaseColumns):
        ANSWERED_EXTERNALLY_TYPE: typing.ClassVar[int] = ...
        ASSERTED_DISPLAY_NAME: typing.ClassVar[str] = ...
        AUTO_MISSED_EMERGENCY_CALL: typing.ClassVar[int] = ...
        AUTO_MISSED_MAXIMUM_DIALING: typing.ClassVar[int] = ...
        AUTO_MISSED_MAXIMUM_RINGING: typing.ClassVar[int] = ...
        BLOCKED_TYPE: typing.ClassVar[int] = ...
        BLOCK_REASON: typing.ClassVar[str] = ...
        BLOCK_REASON_BLOCKED_NUMBER: typing.ClassVar[int] = ...
        BLOCK_REASON_CALL_SCREENING_SERVICE: typing.ClassVar[int] = ...
        BLOCK_REASON_DIRECT_TO_VOICEMAIL: typing.ClassVar[int] = ...
        BLOCK_REASON_NOT_BLOCKED: typing.ClassVar[int] = ...
        BLOCK_REASON_NOT_IN_CONTACTS: typing.ClassVar[int] = ...
        BLOCK_REASON_PAY_PHONE: typing.ClassVar[int] = ...
        BLOCK_REASON_RESTRICTED_NUMBER: typing.ClassVar[int] = ...
        BLOCK_REASON_UNKNOWN_NUMBER: typing.ClassVar[int] = ...
        CACHED_FORMATTED_NUMBER: typing.ClassVar[str] = ...
        CACHED_LOOKUP_URI: typing.ClassVar[str] = ...
        CACHED_MATCHED_NUMBER: typing.ClassVar[str] = ...
        CACHED_NAME: typing.ClassVar[str] = ...
        CACHED_NORMALIZED_NUMBER: typing.ClassVar[str] = ...
        CACHED_NUMBER_LABEL: typing.ClassVar[str] = ...
        CACHED_NUMBER_TYPE: typing.ClassVar[str] = ...
        CACHED_PHOTO_ID: typing.ClassVar[str] = ...
        CACHED_PHOTO_URI: typing.ClassVar[str] = ...
        CALL_SCREENING_APP_NAME: typing.ClassVar[str] = ...
        CALL_SCREENING_COMPONENT_NAME: typing.ClassVar[str] = ...
        COMPOSER_PHOTO_URI: typing.ClassVar[str] = ...
        CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI_WITH_VOICEMAIL: typing.ClassVar[android.net.Uri] = ...
        COUNTRY_ISO: typing.ClassVar[str] = ...
        DATA_USAGE: typing.ClassVar[str] = ...
        DATE: typing.ClassVar[str] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        DURATION: typing.ClassVar[str] = ...
        EXTRA_CALL_TYPE_FILTER: typing.ClassVar[str] = ...
        FEATURES: typing.ClassVar[str] = ...
        FEATURES_ASSISTED_DIALING_USED: typing.ClassVar[int] = ...
        FEATURES_HD_CALL: typing.ClassVar[int] = ...
        FEATURES_PULLED_EXTERNALLY: typing.ClassVar[int] = ...
        FEATURES_RTT: typing.ClassVar[int] = ...
        FEATURES_VIDEO: typing.ClassVar[int] = ...
        FEATURES_VOLTE: typing.ClassVar[int] = ...
        FEATURES_WIFI: typing.ClassVar[int] = ...
        GEOCODED_LOCATION: typing.ClassVar[str] = ...
        INCOMING_TYPE: typing.ClassVar[int] = ...
        IS_BUSINESS_CALL: typing.ClassVar[str] = ...
        IS_READ: typing.ClassVar[str] = ...
        LAST_MODIFIED: typing.ClassVar[str] = ...
        LIMIT_PARAM_KEY: typing.ClassVar[str] = ...
        LOCATION: typing.ClassVar[str] = ...
        MISSED_REASON: typing.ClassVar[str] = ...
        MISSED_REASON_NOT_MISSED: typing.ClassVar[int] = ...
        MISSED_TYPE: typing.ClassVar[int] = ...
        NEW: typing.ClassVar[str] = ...
        NUMBER: typing.ClassVar[str] = ...
        NUMBER_PRESENTATION: typing.ClassVar[str] = ...
        OFFSET_PARAM_KEY: typing.ClassVar[str] = ...
        OUTGOING_TYPE: typing.ClassVar[int] = ...
        PHONE_ACCOUNT_COMPONENT_NAME: typing.ClassVar[str] = ...
        PHONE_ACCOUNT_ID: typing.ClassVar[str] = ...
        POST_DIAL_DIGITS: typing.ClassVar[str] = ...
        PRESENTATION_ALLOWED: typing.ClassVar[int] = ...
        PRESENTATION_PAYPHONE: typing.ClassVar[int] = ...
        PRESENTATION_RESTRICTED: typing.ClassVar[int] = ...
        PRESENTATION_UNAVAILABLE: typing.ClassVar[int] = ...
        PRESENTATION_UNKNOWN: typing.ClassVar[int] = ...
        PRIORITY: typing.ClassVar[str] = ...
        PRIORITY_NORMAL: typing.ClassVar[int] = ...
        PRIORITY_URGENT: typing.ClassVar[int] = ...
        REJECTED_TYPE: typing.ClassVar[int] = ...
        SUBJECT: typing.ClassVar[str] = ...
        TRANSCRIPTION: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...
        USER_MISSED_CALL_FILTERS_TIMEOUT: typing.ClassVar[int] = ...
        USER_MISSED_CALL_SCREENING_SERVICE_SILENCED: typing.ClassVar[int] = ...
        USER_MISSED_DND_MODE: typing.ClassVar[int] = ...
        USER_MISSED_LOW_RING_VOLUME: typing.ClassVar[int] = ...
        USER_MISSED_NO_ANSWER: typing.ClassVar[int] = ...
        USER_MISSED_NO_VIBRATE: typing.ClassVar[int] = ...
        USER_MISSED_SHORT_RING: typing.ClassVar[int] = ...
        VIA_NUMBER: typing.ClassVar[str] = ...
        VOICEMAIL_TYPE: typing.ClassVar[int] = ...
        VOICEMAIL_URI: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @staticmethod
        def getLastOutgoingCall(context: android.content.Context, /) -> str: ...

class CloudMediaProvider(android.content.ContentProvider):
    def __init__(self) -> None: ...
    def attachInfo(self, context: android.content.Context, info: android.content.pm.ProviderInfo, /) -> None: ...
    def call(self, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle: ...
    def canonicalize(self, uri: android.net.Uri, /) -> android.net.Uri: ...
    def delete(self, uri: android.net.Uri, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def getType(self, uri: android.net.Uri, /) -> str: ...
    def insert(self, uri: android.net.Uri, values: android.content.ContentValues, /) -> android.net.Uri: ...
    def onCreateCloudMediaSurfaceController(self, config: android.os.Bundle, callback: CloudMediaProvider.CloudMediaSurfaceStateChangedCallback, /) -> CloudMediaProvider.CloudMediaSurfaceController | None: ...
    def onGetCapabilities(self) -> CloudMediaProviderContract.Capabilities: ...
    def onGetMediaCollectionInfo(self, arg1: android.os.Bundle, /) -> android.os.Bundle: ...
    def onOpenMedia(self, arg1: str | java.lang.String, arg2: android.os.Bundle, arg3: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor: ...
    def onOpenPreview(self, arg1: str | java.lang.String, arg2: android.graphics.Point, arg3: android.os.Bundle, arg4: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    def onQueryAlbums(self, extras: android.os.Bundle, /) -> android.database.Cursor: ...
    def onQueryDeletedMedia(self, arg1: android.os.Bundle, /) -> android.database.Cursor: ...
    def onQueryMedia(self, arg1: android.os.Bundle, /) -> android.database.Cursor: ...
    def onQueryMediaCategories(self, parentCategoryId: str | java.lang.String, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    def onQueryMediaInMediaSet(self, mediaSetId: str | java.lang.String, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    def onQueryMediaSets(self, mediaCategoryId: str | java.lang.String, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    def onQuerySearchSuggestions(self, prefixText: str | java.lang.String, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def onSearchMedia(self, searchText: str | java.lang.String, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def onSearchMedia(self, suggestedMediaSetId: str | java.lang.String, fallbackSearchText: str | java.lang.String, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.os.ParcelFileDescriptor: ...
    @typing.overload
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor: ...
    @typing.overload
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, /) -> android.content.res.AssetFileDescriptor: ...
    @typing.overload
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    def update(self, uri: android.net.Uri, values: android.content.ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...

    class CloudMediaSurfaceStateChangedCallback(java.lang.Object):
        PLAYBACK_STATE_BUFFERING: typing.ClassVar[int] = ...
        PLAYBACK_STATE_COMPLETED: typing.ClassVar[int] = ...
        PLAYBACK_STATE_ERROR_PERMANENT_FAILURE: typing.ClassVar[int] = ...
        PLAYBACK_STATE_ERROR_RETRIABLE_FAILURE: typing.ClassVar[int] = ...
        PLAYBACK_STATE_MEDIA_SIZE_CHANGED: typing.ClassVar[int] = ...
        PLAYBACK_STATE_PAUSED: typing.ClassVar[int] = ...
        PLAYBACK_STATE_READY: typing.ClassVar[int] = ...
        PLAYBACK_STATE_STARTED: typing.ClassVar[int] = ...
        def setPlaybackState(self, surfaceId: int | java.jint | java.lang.Integer, playbackState: int | java.jint | java.lang.Integer, playbackStateInfo: android.os.Bundle, /) -> None: ...

    class CloudMediaSurfaceController(java.lang.Object):
        def __init__(self) -> None: ...
        def onConfigChange(self, arg1: android.os.Bundle, /) -> None: ...
        def onDestroy(self) -> None: ...
        def onMediaPause(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onMediaPlay(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onMediaSeekTo(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
        def onPlayerCreate(self) -> None: ...
        def onPlayerRelease(self) -> None: ...
        def onSurfaceChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSurfaceCreated(self, arg1: int | java.jint | java.lang.Integer, arg2: android.view.Surface, arg3: str | java.lang.String, /) -> None: ...
        def onSurfaceDestroyed(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class CloudMediaProviderContract(java.lang.Object):
    EXTRA_ALBUM_ID: typing.ClassVar[str] = ...
    EXTRA_LOOPING_PLAYBACK_ENABLED: typing.ClassVar[str] = ...
    EXTRA_MEDIA_COLLECTION_ID: typing.ClassVar[str] = ...
    EXTRA_PAGE_SIZE: typing.ClassVar[str] = ...
    EXTRA_PAGE_TOKEN: typing.ClassVar[str] = ...
    EXTRA_PREVIEW_THUMBNAIL: typing.ClassVar[str] = ...
    EXTRA_SORT_ORDER: typing.ClassVar[str] = ...
    EXTRA_SURFACE_CONTROLLER_AUDIO_MUTE_ENABLED: typing.ClassVar[str] = ...
    EXTRA_SYNC_GENERATION: typing.ClassVar[str] = ...
    MANAGE_CLOUD_MEDIA_PROVIDERS_PERMISSION: typing.ClassVar[str] = ...
    MEDIA_CATEGORY_TYPE_PEOPLE_AND_PETS: typing.ClassVar[str] = ...
    PROVIDER_INTERFACE: typing.ClassVar[str] = ...
    SEARCH_SUGGESTION_ALBUM: typing.ClassVar[str] = ...
    SEARCH_SUGGESTION_DATE: typing.ClassVar[str] = ...
    SEARCH_SUGGESTION_FACE: typing.ClassVar[str] = ...
    SEARCH_SUGGESTION_LOCATION: typing.ClassVar[str] = ...
    SEARCH_SUGGESTION_TEXT: typing.ClassVar[str] = ...
    SORT_ORDER_DESC_DATE_TAKEN: typing.ClassVar[int] = ...

    class SearchSuggestionColumns(java.lang.Object):
        DISPLAY_TEXT: typing.ClassVar[str] = ...
        MEDIA_COVER_ID: typing.ClassVar[str] = ...
        MEDIA_SET_ID: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...

    class MediaSetColumns(java.lang.Object):
        DISPLAY_NAME: typing.ClassVar[str] = ...
        ID: typing.ClassVar[str] = ...
        MEDIA_COUNT: typing.ClassVar[str] = ...
        MEDIA_COVER_ID: typing.ClassVar[str] = ...

    class MediaColumns(java.lang.Object):
        DATE_TAKEN_MILLIS: typing.ClassVar[str] = ...
        DURATION_MILLIS: typing.ClassVar[str] = ...
        HEIGHT: typing.ClassVar[str] = ...
        ID: typing.ClassVar[str] = ...
        IS_FAVORITE: typing.ClassVar[str] = ...
        MEDIA_STORE_URI: typing.ClassVar[str] = ...
        MIME_TYPE: typing.ClassVar[str] = ...
        ORIENTATION: typing.ClassVar[str] = ...
        SIZE_BYTES: typing.ClassVar[str] = ...
        STANDARD_MIME_TYPE_EXTENSION: typing.ClassVar[str] = ...
        STANDARD_MIME_TYPE_EXTENSION_ANIMATED_WEBP: typing.ClassVar[int] = ...
        STANDARD_MIME_TYPE_EXTENSION_GIF: typing.ClassVar[int] = ...
        STANDARD_MIME_TYPE_EXTENSION_MOTION_PHOTO: typing.ClassVar[int] = ...
        STANDARD_MIME_TYPE_EXTENSION_NONE: typing.ClassVar[int] = ...
        SYNC_GENERATION: typing.ClassVar[str] = ...
        WIDTH: typing.ClassVar[str] = ...

    class MediaCollectionInfo(java.lang.Object):
        ACCOUNT_CONFIGURATION_INTENT: typing.ClassVar[str] = ...
        ACCOUNT_NAME: typing.ClassVar[str] = ...
        LAST_MEDIA_SYNC_GENERATION: typing.ClassVar[str] = ...
        MEDIA_COLLECTION_ID: typing.ClassVar[str] = ...

    class MediaCategoryColumns(java.lang.Object):
        DISPLAY_NAME: typing.ClassVar[str] = ...
        ID: typing.ClassVar[str] = ...
        MEDIA_CATEGORY_TYPE: typing.ClassVar[str] = ...
        MEDIA_COVER_ID1: typing.ClassVar[str] = ...
        MEDIA_COVER_ID2: typing.ClassVar[str] = ...
        MEDIA_COVER_ID3: typing.ClassVar[str] = ...
        MEDIA_COVER_ID4: typing.ClassVar[str] = ...

    class Capabilities(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CloudMediaProviderContract.Capabilities]] = ...
        def describeContents(self) -> int: ...
        def isMediaCategoriesEnabled(self) -> bool: ...
        def isSearchEnabled(self) -> bool: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> CloudMediaProviderContract.Capabilities: ...
            def setMediaCategoriesEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> CloudMediaProviderContract.Capabilities.Builder: ...
            def setSearchEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> CloudMediaProviderContract.Capabilities.Builder: ...

    class AlbumColumns(java.lang.Object):
        DATE_TAKEN_MILLIS: typing.ClassVar[str] = ...
        DISPLAY_NAME: typing.ClassVar[str] = ...
        ID: typing.ClassVar[str] = ...
        MEDIA_COUNT: typing.ClassVar[str] = ...
        MEDIA_COVER_ID: typing.ClassVar[str] = ...

class Contacts(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
    KIND_EMAIL: typing.ClassVar[int] = ...
    KIND_IM: typing.ClassVar[int] = ...
    KIND_ORGANIZATION: typing.ClassVar[int] = ...
    KIND_PHONE: typing.ClassVar[int] = ...
    KIND_POSTAL: typing.ClassVar[int] = ...

    class SettingsColumns(java.lang.Object):
        KEY: typing.ClassVar[str] = ...
        VALUE: typing.ClassVar[str] = ...
        _SYNC_ACCOUNT: typing.ClassVar[str] = ...
        _SYNC_ACCOUNT_TYPE: typing.ClassVar[str] = ...

    class Settings(BaseColumns, Contacts.SettingsColumns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        SYNC_EVERYTHING: typing.ClassVar[str] = ...
        @staticmethod
        def getSetting(cr: android.content.ContentResolver, account: str | java.lang.String, key: str | java.lang.String, /) -> str: ...
        @staticmethod
        def setSetting(cr: android.content.ContentResolver, account: str | java.lang.String, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...

    class PresenceColumns(java.lang.Object):
        AVAILABLE: typing.ClassVar[int] = ...
        AWAY: typing.ClassVar[int] = ...
        DO_NOT_DISTURB: typing.ClassVar[int] = ...
        IDLE: typing.ClassVar[int] = ...
        IM_ACCOUNT: typing.ClassVar[str] = ...
        IM_HANDLE: typing.ClassVar[str] = ...
        IM_PROTOCOL: typing.ClassVar[str] = ...
        INVISIBLE: typing.ClassVar[int] = ...
        OFFLINE: typing.ClassVar[int] = ...
        PRESENCE_CUSTOM_STATUS: typing.ClassVar[str] = ...
        PRESENCE_STATUS: typing.ClassVar[str] = ...
        PRIORITY: typing.ClassVar[str] = ...

    class PhotosColumns(java.lang.Object):
        DATA: typing.ClassVar[str] = ...
        DOWNLOAD_REQUIRED: typing.ClassVar[str] = ...
        EXISTS_ON_SERVER: typing.ClassVar[str] = ...
        LOCAL_VERSION: typing.ClassVar[str] = ...
        PERSON_ID: typing.ClassVar[str] = ...
        SYNC_ERROR: typing.ClassVar[str] = ...

    class Photos(BaseColumns, Contacts.PhotosColumns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

    class PhonesColumns(java.lang.Object):
        ISPRIMARY: typing.ClassVar[str] = ...
        LABEL: typing.ClassVar[str] = ...
        NUMBER: typing.ClassVar[str] = ...
        NUMBER_KEY: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...
        TYPE_CUSTOM: typing.ClassVar[int] = ...
        TYPE_FAX_HOME: typing.ClassVar[int] = ...
        TYPE_FAX_WORK: typing.ClassVar[int] = ...
        TYPE_HOME: typing.ClassVar[int] = ...
        TYPE_MOBILE: typing.ClassVar[int] = ...
        TYPE_OTHER: typing.ClassVar[int] = ...
        TYPE_PAGER: typing.ClassVar[int] = ...
        TYPE_WORK: typing.ClassVar[int] = ...

    class Phones(BaseColumns, Contacts.PeopleColumns, Contacts.PhonesColumns):
        CONTENT_FILTER_URL: typing.ClassVar[android.net.Uri] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        PERSON_ID: typing.ClassVar[str] = ...
        @typing.overload
        @staticmethod
        def getDisplayLabel(context: android.content.Context, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
        @typing.overload
        @staticmethod
        def getDisplayLabel(context: android.content.Context, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, labelArray: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> java.lang.CharSequence: ...

    class PeopleColumns(java.lang.Object):
        CUSTOM_RINGTONE: typing.ClassVar[str] = ...
        DISPLAY_NAME: typing.ClassVar[str] = ...
        LAST_TIME_CONTACTED: typing.ClassVar[str] = ...
        NAME: typing.ClassVar[str] = ...
        NOTES: typing.ClassVar[str] = ...
        PHONETIC_NAME: typing.ClassVar[str] = ...
        PHOTO_VERSION: typing.ClassVar[str] = ...
        SEND_TO_VOICEMAIL: typing.ClassVar[str] = ...
        STARRED: typing.ClassVar[str] = ...
        TIMES_CONTACTED: typing.ClassVar[str] = ...

    class People(BaseColumns, Contacts.PeopleColumns, Contacts.PhonesColumns, Contacts.PresenceColumns):
        CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        DELETED_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        PRIMARY_EMAIL_ID: typing.ClassVar[str] = ...
        PRIMARY_ORGANIZATION_ID: typing.ClassVar[str] = ...
        PRIMARY_PHONE_ID: typing.ClassVar[str] = ...
        @typing.overload
        @staticmethod
        def addToGroup(resolver: android.content.ContentResolver, personId: int | java.jlong | java.lang.Long, groupId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
        @typing.overload
        @staticmethod
        def addToGroup(resolver: android.content.ContentResolver, personId: int | java.jlong | java.lang.Long, groupName: str | java.lang.String, /) -> android.net.Uri: ...
        @staticmethod
        def addToMyContactsGroup(resolver: android.content.ContentResolver, personId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
        @staticmethod
        def createPersonInMyContactsGroup(resolver: android.content.ContentResolver, values: android.content.ContentValues, /) -> android.net.Uri: ...
        @staticmethod
        def loadContactPhoto(context: android.content.Context, person: android.net.Uri, placeholderImageResource: int | java.jint | java.lang.Integer, options: android.graphics.BitmapFactory.Options, /) -> android.graphics.Bitmap: ...
        @staticmethod
        def markAsContacted(resolver: android.content.ContentResolver, personId: int | java.jlong | java.lang.Long, /) -> None: ...
        @staticmethod
        def openContactPhotoInputStream(cr: android.content.ContentResolver, person: android.net.Uri, /) -> java.io.InputStream: ...
        @staticmethod
        def queryGroups(resolver: android.content.ContentResolver, person: int | java.jlong | java.lang.Long, /) -> android.database.Cursor: ...
        @staticmethod
        def setPhotoData(cr: android.content.ContentResolver, person: android.net.Uri, data: java.chaquopy.JavaArrayJByte, /) -> None: ...

        class Phones(BaseColumns, Contacts.PeopleColumns, Contacts.PhonesColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Extensions(BaseColumns, Contacts.ExtensionsColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            PERSON_ID: typing.ClassVar[str] = ...

        class ContactMethods(BaseColumns, Contacts.ContactMethodsColumns, Contacts.PeopleColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

    class Organizations(BaseColumns, Contacts.OrganizationColumns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        @staticmethod
        def getDisplayLabel(context: android.content.Context, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...

    class OrganizationColumns(java.lang.Object):
        COMPANY: typing.ClassVar[str] = ...
        ISPRIMARY: typing.ClassVar[str] = ...
        LABEL: typing.ClassVar[str] = ...
        PERSON_ID: typing.ClassVar[str] = ...
        TITLE: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...
        TYPE_CUSTOM: typing.ClassVar[int] = ...
        TYPE_OTHER: typing.ClassVar[int] = ...
        TYPE_WORK: typing.ClassVar[int] = ...

    class Intents(java.lang.Object):
        ATTACH_IMAGE: typing.ClassVar[str] = ...
        EXTRA_CREATE_DESCRIPTION: typing.ClassVar[str] = ...
        EXTRA_FORCE_CREATE: typing.ClassVar[str] = ...
        SEARCH_SUGGESTION_CLICKED: typing.ClassVar[str] = ...
        SEARCH_SUGGESTION_CREATE_CONTACT_CLICKED: typing.ClassVar[str] = ...
        SEARCH_SUGGESTION_DIAL_NUMBER_CLICKED: typing.ClassVar[str] = ...
        SHOW_OR_CREATE_CONTACT: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

        class UI(java.lang.Object):
            FILTER_CONTACTS_ACTION: typing.ClassVar[str] = ...
            FILTER_TEXT_EXTRA_KEY: typing.ClassVar[str] = ...
            GROUP_NAME_EXTRA_KEY: typing.ClassVar[str] = ...
            LIST_ALL_CONTACTS_ACTION: typing.ClassVar[str] = ...
            LIST_CONTACTS_WITH_PHONES_ACTION: typing.ClassVar[str] = ...
            LIST_DEFAULT: typing.ClassVar[str] = ...
            LIST_FREQUENT_ACTION: typing.ClassVar[str] = ...
            LIST_GROUP_ACTION: typing.ClassVar[str] = ...
            LIST_STARRED_ACTION: typing.ClassVar[str] = ...
            LIST_STREQUENT_ACTION: typing.ClassVar[str] = ...
            TITLE_EXTRA_KEY: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...

        class Insert(java.lang.Object):
            ACTION: typing.ClassVar[str] = ...
            COMPANY: typing.ClassVar[str] = ...
            EMAIL: typing.ClassVar[str] = ...
            EMAIL_ISPRIMARY: typing.ClassVar[str] = ...
            EMAIL_TYPE: typing.ClassVar[str] = ...
            FULL_MODE: typing.ClassVar[str] = ...
            IM_HANDLE: typing.ClassVar[str] = ...
            IM_ISPRIMARY: typing.ClassVar[str] = ...
            IM_PROTOCOL: typing.ClassVar[str] = ...
            JOB_TITLE: typing.ClassVar[str] = ...
            NAME: typing.ClassVar[str] = ...
            NOTES: typing.ClassVar[str] = ...
            PHONE: typing.ClassVar[str] = ...
            PHONETIC_NAME: typing.ClassVar[str] = ...
            PHONE_ISPRIMARY: typing.ClassVar[str] = ...
            PHONE_TYPE: typing.ClassVar[str] = ...
            POSTAL: typing.ClassVar[str] = ...
            POSTAL_ISPRIMARY: typing.ClassVar[str] = ...
            POSTAL_TYPE: typing.ClassVar[str] = ...
            SECONDARY_EMAIL: typing.ClassVar[str] = ...
            SECONDARY_EMAIL_TYPE: typing.ClassVar[str] = ...
            SECONDARY_PHONE: typing.ClassVar[str] = ...
            SECONDARY_PHONE_TYPE: typing.ClassVar[str] = ...
            TERTIARY_EMAIL: typing.ClassVar[str] = ...
            TERTIARY_EMAIL_TYPE: typing.ClassVar[str] = ...
            TERTIARY_PHONE: typing.ClassVar[str] = ...
            TERTIARY_PHONE_TYPE: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...

    class GroupsColumns(java.lang.Object):
        NAME: typing.ClassVar[str] = ...
        NOTES: typing.ClassVar[str] = ...
        SHOULD_SYNC: typing.ClassVar[str] = ...
        SYSTEM_ID: typing.ClassVar[str] = ...

    class Groups(BaseColumns, Contacts.GroupsColumns):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        DELETED_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        GROUP_ANDROID_STARRED: typing.ClassVar[str] = ...
        GROUP_MY_CONTACTS: typing.ClassVar[str] = ...

    class GroupMembership(BaseColumns, Contacts.GroupsColumns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        GROUP_ID: typing.ClassVar[str] = ...
        GROUP_SYNC_ACCOUNT: typing.ClassVar[str] = ...
        GROUP_SYNC_ACCOUNT_TYPE: typing.ClassVar[str] = ...
        GROUP_SYNC_ID: typing.ClassVar[str] = ...
        PERSON_ID: typing.ClassVar[str] = ...
        RAW_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

    class ExtensionsColumns(java.lang.Object):
        NAME: typing.ClassVar[str] = ...
        VALUE: typing.ClassVar[str] = ...

    class Extensions(BaseColumns, Contacts.ExtensionsColumns):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        PERSON_ID: typing.ClassVar[str] = ...

    class ContactMethodsColumns(java.lang.Object):
        AUX_DATA: typing.ClassVar[str] = ...
        DATA: typing.ClassVar[str] = ...
        ISPRIMARY: typing.ClassVar[str] = ...
        KIND: typing.ClassVar[str] = ...
        LABEL: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...
        TYPE_CUSTOM: typing.ClassVar[int] = ...
        TYPE_HOME: typing.ClassVar[int] = ...
        TYPE_OTHER: typing.ClassVar[int] = ...
        TYPE_WORK: typing.ClassVar[int] = ...

    class ContactMethods(BaseColumns, Contacts.ContactMethodsColumns, Contacts.PeopleColumns):
        CONTENT_EMAIL_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_EMAIL_TYPE: typing.ClassVar[str] = ...
        CONTENT_EMAIL_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_IM_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_POSTAL_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_POSTAL_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        PERSON_ID: typing.ClassVar[str] = ...
        POSTAL_LOCATION_LATITUDE: typing.ClassVar[str] = ...
        POSTAL_LOCATION_LONGITUDE: typing.ClassVar[str] = ...
        PROTOCOL_AIM: typing.ClassVar[int] = ...
        PROTOCOL_GOOGLE_TALK: typing.ClassVar[int] = ...
        PROTOCOL_ICQ: typing.ClassVar[int] = ...
        PROTOCOL_JABBER: typing.ClassVar[int] = ...
        PROTOCOL_MSN: typing.ClassVar[int] = ...
        PROTOCOL_QQ: typing.ClassVar[int] = ...
        PROTOCOL_SKYPE: typing.ClassVar[int] = ...
        PROTOCOL_YAHOO: typing.ClassVar[int] = ...
        def addPostalLocation(self, context: android.content.Context, postalId: int | java.jlong | java.lang.Long, latitude: float | java.jdouble | java.lang.Double, longitude: float | java.jdouble | java.lang.Double, /) -> None: ...
        @staticmethod
        def decodeImProtocol(encodedString: str | java.lang.String, /) -> java.lang.Object: ...
        @staticmethod
        def encodeCustomImProtocol(protocolString: str | java.lang.String, /) -> str: ...
        @staticmethod
        def encodePredefinedImProtocol(protocol: int | java.jint | java.lang.Integer, /) -> str: ...
        @staticmethod
        def getDisplayLabel(context: android.content.Context, kind: int | java.jint | java.lang.Integer, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...

class ContactsContract(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    AUTHORITY_URI: typing.ClassVar[android.net.Uri] = ...
    CALLER_IS_SYNCADAPTER: typing.ClassVar[str] = ...
    DEFERRED_SNIPPETING: typing.ClassVar[str] = ...
    DEFERRED_SNIPPETING_QUERY: typing.ClassVar[str] = ...
    DIRECTORY_PARAM_KEY: typing.ClassVar[str] = ...
    LIMIT_PARAM_KEY: typing.ClassVar[str] = ...
    PRIMARY_ACCOUNT_NAME: typing.ClassVar[str] = ...
    PRIMARY_ACCOUNT_TYPE: typing.ClassVar[str] = ...
    REMOVE_DUPLICATE_ENTRIES: typing.ClassVar[str] = ...
    STREQUENT_PHONE_ONLY: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def isProfileId(id: int | java.jlong | java.lang.Long, /) -> bool: ...

    class SyncState(SyncStateContract.Columns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def get(provider: android.content.ContentProviderClient, account: android.accounts.Account, /) -> java.chaquopy.JavaArrayJByte: ...
        @staticmethod
        def getWithUri(provider: android.content.ContentProviderClient, account: android.accounts.Account, /) -> android.util.Pair[android.net.Uri, java.chaquopy.JavaArrayJByte]: ...
        @staticmethod
        def newSetOperation(account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> android.content.ContentProviderOperation: ...
        @staticmethod
        def set(provider: android.content.ContentProviderClient, account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> None: ...

    class SyncColumns(ContactsContract.BaseSyncColumns):
        ACCOUNT_NAME: typing.ClassVar[str] = ...
        ACCOUNT_TYPE: typing.ClassVar[str] = ...
        DIRTY: typing.ClassVar[str] = ...
        SOURCE_ID: typing.ClassVar[str] = ...
        VERSION: typing.ClassVar[str] = ...

    class StatusUpdates(ContactsContract.PresenceColumns, ContactsContract.StatusColumns):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        PROFILE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def getPresenceIconResourceId(status: int | java.jint | java.lang.Integer, /) -> int: ...
        @staticmethod
        def getPresencePrecedence(status: int | java.jint | java.lang.Integer, /) -> int: ...

    class StatusColumns(java.lang.Object):
        AVAILABLE: typing.ClassVar[int] = ...
        AWAY: typing.ClassVar[int] = ...
        CAPABILITY_HAS_CAMERA: typing.ClassVar[int] = ...
        CAPABILITY_HAS_VIDEO: typing.ClassVar[int] = ...
        CAPABILITY_HAS_VOICE: typing.ClassVar[int] = ...
        CHAT_CAPABILITY: typing.ClassVar[str] = ...
        DO_NOT_DISTURB: typing.ClassVar[int] = ...
        IDLE: typing.ClassVar[int] = ...
        INVISIBLE: typing.ClassVar[int] = ...
        OFFLINE: typing.ClassVar[int] = ...
        PRESENCE: typing.ClassVar[str] = ...
        PRESENCE_CUSTOM_STATUS: typing.ClassVar[str] = ...
        PRESENCE_STATUS: typing.ClassVar[str] = ...
        STATUS: typing.ClassVar[str] = ...
        STATUS_ICON: typing.ClassVar[str] = ...
        STATUS_LABEL: typing.ClassVar[str] = ...
        STATUS_RES_PACKAGE: typing.ClassVar[str] = ...
        STATUS_TIMESTAMP: typing.ClassVar[str] = ...

    class SimContacts(java.lang.Object):
        ACTION_SIM_ACCOUNTS_CHANGED: typing.ClassVar[str] = ...
        @staticmethod
        def getSimAccounts(contentResolver: android.content.ContentResolver, /) -> java.util.List[ContactsContract.SimAccount]: ...

    class SimAccount(android.os.Parcelable):
        ADN_EF_TYPE: typing.ClassVar[int] = ...
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContactsContract.SimAccount]] = ...
        FDN_EF_TYPE: typing.ClassVar[int] = ...
        SDN_EF_TYPE: typing.ClassVar[int] = ...
        UNKNOWN_EF_TYPE: typing.ClassVar[int] = ...
        def describeContents(self) -> int: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAccountName(self) -> str: ...
        def getAccountType(self) -> str: ...
        def getEfType(self) -> int: ...
        def getSimSlotIndex(self) -> int: ...
        def hashCode(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class SettingsColumns(java.lang.Object):
        ACCOUNT_NAME: typing.ClassVar[str] = ...
        ACCOUNT_TYPE: typing.ClassVar[str] = ...
        ANY_UNSYNCED: typing.ClassVar[str] = ...
        DATA_SET: typing.ClassVar[str] = ...
        SHOULD_SYNC: typing.ClassVar[str] = ...
        UNGROUPED_COUNT: typing.ClassVar[str] = ...
        UNGROUPED_VISIBLE: typing.ClassVar[str] = ...
        UNGROUPED_WITH_PHONES: typing.ClassVar[str] = ...

    class Settings(ContactsContract.SettingsColumns):
        ACTION_SET_DEFAULT_ACCOUNT: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def getDefaultAccount(resolver: android.content.ContentResolver, /) -> android.accounts.Account: ...

    class SearchSnippets(java.lang.Object):
        DEFERRED_SNIPPETING_KEY: typing.ClassVar[str] = ...
        SNIPPET: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

    class RawContactsEntity(BaseColumns, ContactsContract.DataColumns, ContactsContract.RawContactsColumns):
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATA_ID: typing.ClassVar[str] = ...
        PROFILE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...

    class RawContactsColumns(java.lang.Object):
        ACCOUNT_TYPE_AND_DATA_SET: typing.ClassVar[str] = ...
        AGGREGATION_MODE: typing.ClassVar[str] = ...
        BACKUP_ID: typing.ClassVar[str] = ...
        CONTACT_ID: typing.ClassVar[str] = ...
        DATA_SET: typing.ClassVar[str] = ...
        DELETED: typing.ClassVar[str] = ...
        METADATA_DIRTY: typing.ClassVar[str] = ...
        RAW_CONTACT_IS_READ_ONLY: typing.ClassVar[str] = ...
        RAW_CONTACT_IS_USER_PROFILE: typing.ClassVar[str] = ...

    class RawContacts(BaseColumns, ContactsContract.ContactNameColumns, ContactsContract.ContactOptionsColumns, ContactsContract.RawContactsColumns, ContactsContract.SyncColumns):
        AGGREGATION_MODE_DEFAULT: typing.ClassVar[int] = ...
        AGGREGATION_MODE_DISABLED: typing.ClassVar[int] = ...
        AGGREGATION_MODE_IMMEDIATE: typing.ClassVar[int] = ...
        AGGREGATION_MODE_SUSPENDED: typing.ClassVar[int] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def getContactLookupUri(resolver: android.content.ContentResolver, rawContactUri: android.net.Uri, /) -> android.net.Uri: ...
        @staticmethod
        def getLocalAccountName(context: android.content.Context, /) -> str: ...
        @staticmethod
        def getLocalAccountType(context: android.content.Context, /) -> str: ...
        @staticmethod
        def newEntityIterator(cursor: android.database.Cursor, /) -> android.content.EntityIterator: ...

        class Entity(BaseColumns, ContactsContract.DataColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...
            DATA_ID: typing.ClassVar[str] = ...

        class DisplayPhoto(java.lang.Object):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...

        class DefaultAccount(java.lang.Object):
            ACTION_MOVE_CONTACTS_TO_DEFAULT_ACCOUNT: typing.ClassVar[str] = ...
            @staticmethod
            def getDefaultAccountForNewContacts(resolver: android.content.ContentResolver, /) -> ContactsContract.RawContacts.DefaultAccount.DefaultAccountAndState: ...

            class DefaultAccountAndState(java.lang.Object):
                DEFAULT_ACCOUNT_STATE_CLOUD: typing.ClassVar[int] = ...
                DEFAULT_ACCOUNT_STATE_LOCAL: typing.ClassVar[int] = ...
                DEFAULT_ACCOUNT_STATE_NOT_SET: typing.ClassVar[int] = ...
                DEFAULT_ACCOUNT_STATE_SIM: typing.ClassVar[int] = ...
                def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
                def getAccount(self) -> android.accounts.Account: ...
                def getState(self) -> int: ...
                def hashCode(self) -> int: ...
                @staticmethod
                def ofCloud(cloudAccount: android.accounts.Account, /) -> ContactsContract.RawContacts.DefaultAccount.DefaultAccountAndState: ...
                @staticmethod
                def ofLocal() -> ContactsContract.RawContacts.DefaultAccount.DefaultAccountAndState: ...
                @staticmethod
                def ofNotSet() -> ContactsContract.RawContacts.DefaultAccount.DefaultAccountAndState: ...
                @staticmethod
                def ofSim(simAccount: android.accounts.Account, /) -> ContactsContract.RawContacts.DefaultAccount.DefaultAccountAndState: ...

        class Data(BaseColumns, ContactsContract.DataColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...

    class QuickContact(java.lang.Object):
        ACTION_QUICK_CONTACT: typing.ClassVar[str] = ...
        EXTRA_EXCLUDE_MIMES: typing.ClassVar[str] = ...
        EXTRA_MODE: typing.ClassVar[str] = ...
        EXTRA_PRIORITIZED_MIMETYPE: typing.ClassVar[str] = ...
        MODE_LARGE: typing.ClassVar[int] = ...
        MODE_MEDIUM: typing.ClassVar[int] = ...
        MODE_SMALL: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        @typing.overload
        @staticmethod
        def showQuickContact(context: android.content.Context, target: android.graphics.Rect, lookupUri: android.net.Uri, mode: int | java.jint | java.lang.Integer, excludeMimes: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
        @typing.overload
        @staticmethod
        def showQuickContact(context: android.content.Context, target: android.graphics.Rect, lookupUri: android.net.Uri, excludeMimes: java.chaquopy.JavaArray[java.lang.String], prioritizedMimeType: str | java.lang.String, /) -> None: ...
        @typing.overload
        @staticmethod
        def showQuickContact(context: android.content.Context, target: android.view.View, lookupUri: android.net.Uri, mode: int | java.jint | java.lang.Integer, excludeMimes: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
        @typing.overload
        @staticmethod
        def showQuickContact(context: android.content.Context, target: android.view.View, lookupUri: android.net.Uri, excludeMimes: java.chaquopy.JavaArray[java.lang.String], prioritizedMimeType: str | java.lang.String, /) -> None: ...

    class ProviderStatus(java.lang.Object):
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATABASE_CREATION_TIMESTAMP: typing.ClassVar[str] = ...
        STATUS: typing.ClassVar[str] = ...
        STATUS_BUSY: typing.ClassVar[int] = ...
        STATUS_EMPTY: typing.ClassVar[int] = ...
        STATUS_NORMAL: typing.ClassVar[int] = ...

    class ProfileSyncState(SyncStateContract.Columns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def get(provider: android.content.ContentProviderClient, account: android.accounts.Account, /) -> java.chaquopy.JavaArrayJByte: ...
        @staticmethod
        def getWithUri(provider: android.content.ContentProviderClient, account: android.accounts.Account, /) -> android.util.Pair[android.net.Uri, java.chaquopy.JavaArrayJByte]: ...
        @staticmethod
        def newSetOperation(account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> android.content.ContentProviderOperation: ...
        @staticmethod
        def set(provider: android.content.ContentProviderClient, account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> None: ...

    class Profile(BaseColumns, ContactsContract.ContactNameColumns, ContactsContract.ContactOptionsColumns, ContactsContract.ContactStatusColumns, ContactsContract.ContactsColumns):
        CONTENT_RAW_CONTACTS_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_VCARD_URI: typing.ClassVar[android.net.Uri] = ...
        MIN_ID: typing.ClassVar[int] = ...

    class PresenceColumns(java.lang.Object):
        CUSTOM_PROTOCOL: typing.ClassVar[str] = ...
        DATA_ID: typing.ClassVar[str] = ...
        IM_ACCOUNT: typing.ClassVar[str] = ...
        IM_HANDLE: typing.ClassVar[str] = ...
        PROTOCOL: typing.ClassVar[str] = ...

    class Presence(ContactsContract.StatusUpdates):
        def __init__(self) -> None: ...

    class PinnedPositions(java.lang.Object):
        DEMOTED: typing.ClassVar[int] = ...
        UNPINNED: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        @staticmethod
        def pin(contentResolver: android.content.ContentResolver, contactId: int | java.jlong | java.lang.Long, pinnedPosition: int | java.jint | java.lang.Integer, /) -> None: ...
        @staticmethod
        def undemote(contentResolver: android.content.ContentResolver, contactId: int | java.jlong | java.lang.Long, /) -> None: ...

    class PhoneticNameStyle(java.lang.Object):
        JAPANESE: typing.ClassVar[int] = ...
        KOREAN: typing.ClassVar[int] = ...
        PINYIN: typing.ClassVar[int] = ...
        UNDEFINED: typing.ClassVar[int] = ...

    class PhoneLookupColumns(java.lang.Object):
        CONTACT_ID: typing.ClassVar[str] = ...
        DATA_ID: typing.ClassVar[str] = ...
        LABEL: typing.ClassVar[str] = ...
        NORMALIZED_NUMBER: typing.ClassVar[str] = ...
        NUMBER: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...

    class PhoneLookup(BaseColumns, ContactsContract.ContactNameColumns, ContactsContract.ContactOptionsColumns, ContactsContract.ContactsColumns, ContactsContract.PhoneLookupColumns):
        CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        QUERY_PARAMETER_SIP_ADDRESS: typing.ClassVar[str] = ...

    class Intents(java.lang.Object):
        ACTION_VOICE_SEND_MESSAGE_TO_CONTACTS: typing.ClassVar[str] = ...
        ATTACH_IMAGE: typing.ClassVar[str] = ...
        CONTACTS_DATABASE_CREATED: typing.ClassVar[str] = ...
        EXTRA_CREATE_DESCRIPTION: typing.ClassVar[str] = ...
        EXTRA_FORCE_CREATE: typing.ClassVar[str] = ...
        EXTRA_RECIPIENT_CONTACT_CHAT_ID: typing.ClassVar[str] = ...
        EXTRA_RECIPIENT_CONTACT_NAME: typing.ClassVar[str] = ...
        EXTRA_RECIPIENT_CONTACT_URI: typing.ClassVar[str] = ...
        INVITE_CONTACT: typing.ClassVar[str] = ...
        METADATA_ACCOUNT_TYPE: typing.ClassVar[str] = ...
        METADATA_MIMETYPE: typing.ClassVar[str] = ...
        SEARCH_SUGGESTION_CLICKED: typing.ClassVar[str] = ...
        SEARCH_SUGGESTION_CREATE_CONTACT_CLICKED: typing.ClassVar[str] = ...
        SEARCH_SUGGESTION_DIAL_NUMBER_CLICKED: typing.ClassVar[str] = ...
        SHOW_OR_CREATE_CONTACT: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

        class Insert(java.lang.Object):
            ACTION: typing.ClassVar[str] = ...
            COMPANY: typing.ClassVar[str] = ...
            DATA: typing.ClassVar[str] = ...
            EMAIL: typing.ClassVar[str] = ...
            EMAIL_ISPRIMARY: typing.ClassVar[str] = ...
            EMAIL_TYPE: typing.ClassVar[str] = ...
            EXTRA_ACCOUNT: typing.ClassVar[str] = ...
            EXTRA_DATA_SET: typing.ClassVar[str] = ...
            FULL_MODE: typing.ClassVar[str] = ...
            IM_HANDLE: typing.ClassVar[str] = ...
            IM_ISPRIMARY: typing.ClassVar[str] = ...
            IM_PROTOCOL: typing.ClassVar[str] = ...
            JOB_TITLE: typing.ClassVar[str] = ...
            NAME: typing.ClassVar[str] = ...
            NOTES: typing.ClassVar[str] = ...
            PHONE: typing.ClassVar[str] = ...
            PHONETIC_NAME: typing.ClassVar[str] = ...
            PHONE_ISPRIMARY: typing.ClassVar[str] = ...
            PHONE_TYPE: typing.ClassVar[str] = ...
            POSTAL: typing.ClassVar[str] = ...
            POSTAL_ISPRIMARY: typing.ClassVar[str] = ...
            POSTAL_TYPE: typing.ClassVar[str] = ...
            SECONDARY_EMAIL: typing.ClassVar[str] = ...
            SECONDARY_EMAIL_TYPE: typing.ClassVar[str] = ...
            SECONDARY_PHONE: typing.ClassVar[str] = ...
            SECONDARY_PHONE_TYPE: typing.ClassVar[str] = ...
            TERTIARY_EMAIL: typing.ClassVar[str] = ...
            TERTIARY_EMAIL_TYPE: typing.ClassVar[str] = ...
            TERTIARY_PHONE: typing.ClassVar[str] = ...
            TERTIARY_PHONE_TYPE: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...

    class GroupsColumns(java.lang.Object):
        AUTO_ADD: typing.ClassVar[str] = ...
        DATA_SET: typing.ClassVar[str] = ...
        DELETED: typing.ClassVar[str] = ...
        FAVORITES: typing.ClassVar[str] = ...
        GROUP_IS_READ_ONLY: typing.ClassVar[str] = ...
        GROUP_VISIBLE: typing.ClassVar[str] = ...
        NOTES: typing.ClassVar[str] = ...
        RES_PACKAGE: typing.ClassVar[str] = ...
        SHOULD_SYNC: typing.ClassVar[str] = ...
        SUMMARY_COUNT: typing.ClassVar[str] = ...
        SUMMARY_WITH_PHONES: typing.ClassVar[str] = ...
        SYSTEM_ID: typing.ClassVar[str] = ...
        TITLE: typing.ClassVar[str] = ...
        TITLE_RES: typing.ClassVar[str] = ...

    class Groups(BaseColumns, ContactsContract.GroupsColumns, ContactsContract.SyncColumns):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_SUMMARY_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @staticmethod
        def newEntityIterator(cursor: android.database.Cursor, /) -> android.content.EntityIterator: ...

    class FullNameStyle(java.lang.Object):
        CHINESE: typing.ClassVar[int] = ...
        CJK: typing.ClassVar[int] = ...
        JAPANESE: typing.ClassVar[int] = ...
        KOREAN: typing.ClassVar[int] = ...
        UNDEFINED: typing.ClassVar[int] = ...
        WESTERN: typing.ClassVar[int] = ...

    class DisplayPhoto(java.lang.Object):
        CONTENT_MAX_DIMENSIONS_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DISPLAY_MAX_DIM: typing.ClassVar[str] = ...
        THUMBNAIL_MAX_DIM: typing.ClassVar[str] = ...

    class DisplayNameSources(java.lang.Object):
        EMAIL: typing.ClassVar[int] = ...
        NICKNAME: typing.ClassVar[int] = ...
        ORGANIZATION: typing.ClassVar[int] = ...
        PHONE: typing.ClassVar[int] = ...
        STRUCTURED_NAME: typing.ClassVar[int] = ...
        STRUCTURED_PHONETIC_NAME: typing.ClassVar[int] = ...
        UNDEFINED: typing.ClassVar[int] = ...

    class Directory(BaseColumns):
        ACCOUNT_NAME: typing.ClassVar[str] = ...
        ACCOUNT_TYPE: typing.ClassVar[str] = ...
        CALLER_PACKAGE_PARAM_KEY: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT: typing.ClassVar[int] = ...
        DIRECTORY_AUTHORITY: typing.ClassVar[str] = ...
        DISPLAY_NAME: typing.ClassVar[str] = ...
        ENTERPRISE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_DEFAULT: typing.ClassVar[int] = ...
        ENTERPRISE_LOCAL_INVISIBLE: typing.ClassVar[int] = ...
        EXPORT_SUPPORT: typing.ClassVar[str] = ...
        EXPORT_SUPPORT_ANY_ACCOUNT: typing.ClassVar[int] = ...
        EXPORT_SUPPORT_NONE: typing.ClassVar[int] = ...
        EXPORT_SUPPORT_SAME_ACCOUNT_ONLY: typing.ClassVar[int] = ...
        LOCAL_INVISIBLE: typing.ClassVar[int] = ...
        PACKAGE_NAME: typing.ClassVar[str] = ...
        PHOTO_SUPPORT: typing.ClassVar[str] = ...
        PHOTO_SUPPORT_FULL: typing.ClassVar[int] = ...
        PHOTO_SUPPORT_FULL_SIZE_ONLY: typing.ClassVar[int] = ...
        PHOTO_SUPPORT_NONE: typing.ClassVar[int] = ...
        PHOTO_SUPPORT_THUMBNAIL_ONLY: typing.ClassVar[int] = ...
        SHORTCUT_SUPPORT: typing.ClassVar[str] = ...
        SHORTCUT_SUPPORT_DATA_ITEMS_ONLY: typing.ClassVar[int] = ...
        SHORTCUT_SUPPORT_FULL: typing.ClassVar[int] = ...
        SHORTCUT_SUPPORT_NONE: typing.ClassVar[int] = ...
        TYPE_RESOURCE_ID: typing.ClassVar[str] = ...
        @staticmethod
        def isEnterpriseDirectoryId(directoryId: int | java.jlong | java.lang.Long, /) -> bool: ...
        @staticmethod
        def isRemoteDirectoryId(directoryId: int | java.jlong | java.lang.Long, /) -> bool: ...
        @staticmethod
        def notifyDirectoryChange(resolver: android.content.ContentResolver, /) -> None: ...

    class DeletedContactsColumns(java.lang.Object):
        CONTACT_DELETED_TIMESTAMP: typing.ClassVar[str] = ...
        CONTACT_ID: typing.ClassVar[str] = ...

    class DeletedContacts(ContactsContract.DeletedContactsColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DAYS_KEPT_MILLISECONDS: typing.ClassVar[int] = ...

    class DataUsageStatColumns(java.lang.Object):
        LAST_TIME_USED: typing.ClassVar[str] = ...
        TIMES_USED: typing.ClassVar[str] = ...

    class DataUsageFeedback(java.lang.Object):
        DELETE_USAGE_URI: typing.ClassVar[android.net.Uri] = ...
        FEEDBACK_URI: typing.ClassVar[android.net.Uri] = ...
        USAGE_TYPE: typing.ClassVar[str] = ...
        USAGE_TYPE_CALL: typing.ClassVar[str] = ...
        USAGE_TYPE_LONG_TEXT: typing.ClassVar[str] = ...
        USAGE_TYPE_SHORT_TEXT: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

    class DataColumnsWithJoins(BaseColumns, ContactsContract.ContactNameColumns, ContactsContract.ContactOptionsColumns, ContactsContract.ContactStatusColumns, ContactsContract.ContactsColumns, ContactsContract.DataColumns, ContactsContract.DataUsageStatColumns, ContactsContract.RawContactsColumns, ContactsContract.StatusColumns): ...

    class DataColumns(java.lang.Object):
        CARRIER_PRESENCE: typing.ClassVar[str] = ...
        CARRIER_PRESENCE_VT_CAPABLE: typing.ClassVar[int] = ...
        DATA10: typing.ClassVar[str] = ...
        DATA11: typing.ClassVar[str] = ...
        DATA12: typing.ClassVar[str] = ...
        DATA13: typing.ClassVar[str] = ...
        DATA14: typing.ClassVar[str] = ...
        DATA15: typing.ClassVar[str] = ...
        DATA1: typing.ClassVar[str] = ...
        DATA2: typing.ClassVar[str] = ...
        DATA3: typing.ClassVar[str] = ...
        DATA4: typing.ClassVar[str] = ...
        DATA5: typing.ClassVar[str] = ...
        DATA6: typing.ClassVar[str] = ...
        DATA7: typing.ClassVar[str] = ...
        DATA8: typing.ClassVar[str] = ...
        DATA9: typing.ClassVar[str] = ...
        DATA_VERSION: typing.ClassVar[str] = ...
        IS_PRIMARY: typing.ClassVar[str] = ...
        IS_READ_ONLY: typing.ClassVar[str] = ...
        IS_SUPER_PRIMARY: typing.ClassVar[str] = ...
        MIMETYPE: typing.ClassVar[str] = ...
        PREFERRED_PHONE_ACCOUNT_COMPONENT_NAME: typing.ClassVar[str] = ...
        PREFERRED_PHONE_ACCOUNT_ID: typing.ClassVar[str] = ...
        RAW_CONTACT_ID: typing.ClassVar[str] = ...
        RES_PACKAGE: typing.ClassVar[str] = ...
        SYNC1: typing.ClassVar[str] = ...
        SYNC2: typing.ClassVar[str] = ...
        SYNC3: typing.ClassVar[str] = ...
        SYNC4: typing.ClassVar[str] = ...

    class Data(ContactsContract.DataColumnsWithJoins):
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
        EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
        EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
        VISIBLE_CONTACTS_ONLY: typing.ClassVar[str] = ...
        @staticmethod
        def getContactLookupUri(resolver: android.content.ContentResolver, dataUri: android.net.Uri, /) -> android.net.Uri: ...

    class ContactsColumns(java.lang.Object):
        CONTACT_LAST_UPDATED_TIMESTAMP: typing.ClassVar[str] = ...
        DISPLAY_NAME: typing.ClassVar[str] = ...
        HAS_PHONE_NUMBER: typing.ClassVar[str] = ...
        IN_DEFAULT_DIRECTORY: typing.ClassVar[str] = ...
        IN_VISIBLE_GROUP: typing.ClassVar[str] = ...
        IS_USER_PROFILE: typing.ClassVar[str] = ...
        LOOKUP_KEY: typing.ClassVar[str] = ...
        NAME_RAW_CONTACT_ID: typing.ClassVar[str] = ...
        PHOTO_FILE_ID: typing.ClassVar[str] = ...
        PHOTO_ID: typing.ClassVar[str] = ...
        PHOTO_THUMBNAIL_URI: typing.ClassVar[str] = ...
        PHOTO_URI: typing.ClassVar[str] = ...

    class Contacts(BaseColumns, ContactsContract.ContactNameColumns, ContactsContract.ContactOptionsColumns, ContactsContract.ContactStatusColumns, ContactsContract.ContactsColumns):
        CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_FREQUENT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_GROUP_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_LOOKUP_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_MULTI_VCARD_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_STREQUENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_STREQUENT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_VCARD_TYPE: typing.ClassVar[str] = ...
        CONTENT_VCARD_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
        ENTERPRISE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
        EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
        EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
        QUERY_PARAMETER_VCARD_NO_PHOTO: typing.ClassVar[str] = ...
        @typing.overload
        @staticmethod
        def getLookupUri(contactId: int | java.jlong | java.lang.Long, lookupKey: str | java.lang.String, /) -> android.net.Uri: ...
        @typing.overload
        @staticmethod
        def getLookupUri(resolver: android.content.ContentResolver, contactUri: android.net.Uri, /) -> android.net.Uri: ...
        @staticmethod
        def isEnterpriseContactId(contactId: int | java.jlong | java.lang.Long, /) -> bool: ...
        @staticmethod
        def lookupContact(resolver: android.content.ContentResolver, lookupUri: android.net.Uri, /) -> android.net.Uri: ...
        @staticmethod
        def markAsContacted(resolver: android.content.ContentResolver, contactId: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        @staticmethod
        def openContactPhotoInputStream(cr: android.content.ContentResolver, contactUri: android.net.Uri, /) -> java.io.InputStream: ...
        @typing.overload
        @staticmethod
        def openContactPhotoInputStream(cr: android.content.ContentResolver, contactUri: android.net.Uri, preferHighres: bool | java.jboolean | java.lang.Boolean, /) -> java.io.InputStream: ...

        class Photo(ContactsContract.DataColumnsWithJoins, BaseColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...
            DISPLAY_PHOTO: typing.ClassVar[str] = ...
            PHOTO: typing.ClassVar[str] = ...
            PHOTO_FILE_ID: typing.ClassVar[str] = ...

        class Entity(ContactsContract.SyncColumns, BaseColumns, ContactsContract.BaseSyncColumns, ContactsContract.ContactNameColumns, ContactsContract.ContactOptionsColumns, ContactsContract.ContactStatusColumns, ContactsContract.ContactsColumns, ContactsContract.DataColumns, ContactsContract.DataUsageStatColumns, ContactsContract.RawContactsColumns, ContactsContract.StatusColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...
            DATA_ID: typing.ClassVar[str] = ...
            RAW_CONTACT_ID: typing.ClassVar[str] = ...

        class Data(BaseColumns, ContactsContract.DataColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...

        class AggregationSuggestions(BaseColumns, ContactsContract.ContactOptionsColumns, ContactsContract.ContactStatusColumns, ContactsContract.ContactsColumns):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...

            class Builder(java.lang.Object):
                def __init__(self) -> None: ...
                def addNameParameter(self, name: str | java.lang.String, /) -> ContactsContract.Contacts.AggregationSuggestions.Builder: ...
                def build(self) -> android.net.Uri: ...
                def setContactId(self, contactId: int | java.jlong | java.lang.Long, /) -> ContactsContract.Contacts.AggregationSuggestions.Builder: ...
                def setLimit(self, limit: int | java.jint | java.lang.Integer, /) -> ContactsContract.Contacts.AggregationSuggestions.Builder: ...

    class ContactStatusColumns(java.lang.Object):
        CONTACT_CHAT_CAPABILITY: typing.ClassVar[str] = ...
        CONTACT_PRESENCE: typing.ClassVar[str] = ...
        CONTACT_STATUS: typing.ClassVar[str] = ...
        CONTACT_STATUS_ICON: typing.ClassVar[str] = ...
        CONTACT_STATUS_LABEL: typing.ClassVar[str] = ...
        CONTACT_STATUS_RES_PACKAGE: typing.ClassVar[str] = ...
        CONTACT_STATUS_TIMESTAMP: typing.ClassVar[str] = ...

    class ContactOptionsColumns(java.lang.Object):
        CUSTOM_RINGTONE: typing.ClassVar[str] = ...
        LAST_TIME_CONTACTED: typing.ClassVar[str] = ...
        PINNED: typing.ClassVar[str] = ...
        SEND_TO_VOICEMAIL: typing.ClassVar[str] = ...
        STARRED: typing.ClassVar[str] = ...
        TIMES_CONTACTED: typing.ClassVar[str] = ...

    class ContactNameColumns(java.lang.Object):
        DISPLAY_NAME_ALTERNATIVE: typing.ClassVar[str] = ...
        DISPLAY_NAME_PRIMARY: typing.ClassVar[str] = ...
        DISPLAY_NAME_SOURCE: typing.ClassVar[str] = ...
        PHONETIC_NAME: typing.ClassVar[str] = ...
        PHONETIC_NAME_STYLE: typing.ClassVar[str] = ...
        SORT_KEY_ALTERNATIVE: typing.ClassVar[str] = ...
        SORT_KEY_PRIMARY: typing.ClassVar[str] = ...

    class CommonDataKinds(java.lang.Object):

        class Website(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            TYPE_BLOG: typing.ClassVar[int] = ...
            TYPE_FTP: typing.ClassVar[int] = ...
            TYPE_HOME: typing.ClassVar[int] = ...
            TYPE_HOMEPAGE: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_PROFILE: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            URL: typing.ClassVar[str] = ...

        class StructuredPostal(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CITY: typing.ClassVar[str] = ...
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            CONTENT_TYPE: typing.ClassVar[str] = ...
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            COUNTRY: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            FORMATTED_ADDRESS: typing.ClassVar[str] = ...
            NEIGHBORHOOD: typing.ClassVar[str] = ...
            POBOX: typing.ClassVar[str] = ...
            POSTCODE: typing.ClassVar[str] = ...
            REGION: typing.ClassVar[str] = ...
            STREET: typing.ClassVar[str] = ...
            TYPE_HOME: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class StructuredName(ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            DISPLAY_NAME: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            FAMILY_NAME: typing.ClassVar[str] = ...
            FULL_NAME_STYLE: typing.ClassVar[str] = ...
            GIVEN_NAME: typing.ClassVar[str] = ...
            MIDDLE_NAME: typing.ClassVar[str] = ...
            PHONETIC_FAMILY_NAME: typing.ClassVar[str] = ...
            PHONETIC_GIVEN_NAME: typing.ClassVar[str] = ...
            PHONETIC_MIDDLE_NAME: typing.ClassVar[str] = ...
            PHONETIC_NAME_STYLE: typing.ClassVar[str] = ...
            PREFIX: typing.ClassVar[str] = ...
            SUFFIX: typing.ClassVar[str] = ...

        class SipAddress(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            SIP_ADDRESS: typing.ClassVar[str] = ...
            TYPE_HOME: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Relation(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            NAME: typing.ClassVar[str] = ...
            TYPE_ASSISTANT: typing.ClassVar[int] = ...
            TYPE_BROTHER: typing.ClassVar[int] = ...
            TYPE_CHILD: typing.ClassVar[int] = ...
            TYPE_DOMESTIC_PARTNER: typing.ClassVar[int] = ...
            TYPE_FATHER: typing.ClassVar[int] = ...
            TYPE_FRIEND: typing.ClassVar[int] = ...
            TYPE_MANAGER: typing.ClassVar[int] = ...
            TYPE_MOTHER: typing.ClassVar[int] = ...
            TYPE_PARENT: typing.ClassVar[int] = ...
            TYPE_PARTNER: typing.ClassVar[int] = ...
            TYPE_REFERRED_BY: typing.ClassVar[int] = ...
            TYPE_RELATIVE: typing.ClassVar[int] = ...
            TYPE_SISTER: typing.ClassVar[int] = ...
            TYPE_SPOUSE: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Photo(ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            PHOTO: typing.ClassVar[str] = ...
            PHOTO_FILE_ID: typing.ClassVar[str] = ...

        class Phone(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            CONTENT_TYPE: typing.ClassVar[str] = ...
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            ENTERPRISE_CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            ENTERPRISE_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            NORMALIZED_NUMBER: typing.ClassVar[str] = ...
            NUMBER: typing.ClassVar[str] = ...
            SEARCH_DISPLAY_NAME_KEY: typing.ClassVar[str] = ...
            SEARCH_PHONE_NUMBER_KEY: typing.ClassVar[str] = ...
            TYPE_ASSISTANT: typing.ClassVar[int] = ...
            TYPE_CALLBACK: typing.ClassVar[int] = ...
            TYPE_CAR: typing.ClassVar[int] = ...
            TYPE_COMPANY_MAIN: typing.ClassVar[int] = ...
            TYPE_FAX_HOME: typing.ClassVar[int] = ...
            TYPE_FAX_WORK: typing.ClassVar[int] = ...
            TYPE_HOME: typing.ClassVar[int] = ...
            TYPE_ISDN: typing.ClassVar[int] = ...
            TYPE_MAIN: typing.ClassVar[int] = ...
            TYPE_MMS: typing.ClassVar[int] = ...
            TYPE_MOBILE: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_OTHER_FAX: typing.ClassVar[int] = ...
            TYPE_PAGER: typing.ClassVar[int] = ...
            TYPE_RADIO: typing.ClassVar[int] = ...
            TYPE_TELEX: typing.ClassVar[int] = ...
            TYPE_TTY_TDD: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            TYPE_WORK_MOBILE: typing.ClassVar[int] = ...
            TYPE_WORK_PAGER: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Organization(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            COMPANY: typing.ClassVar[str] = ...
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            DEPARTMENT: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            JOB_DESCRIPTION: typing.ClassVar[str] = ...
            OFFICE_LOCATION: typing.ClassVar[str] = ...
            PHONETIC_NAME: typing.ClassVar[str] = ...
            PHONETIC_NAME_STYLE: typing.ClassVar[str] = ...
            SYMBOL: typing.ClassVar[str] = ...
            TITLE: typing.ClassVar[str] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Note(ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            NOTE: typing.ClassVar[str] = ...

        class Nickname(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            NAME: typing.ClassVar[str] = ...
            TYPE_DEFAULT: typing.ClassVar[int] = ...
            TYPE_INITIALS: typing.ClassVar[int] = ...
            TYPE_MAIDEN_NAME: typing.ClassVar[int] = ...
            TYPE_MAINDEN_NAME: typing.ClassVar[int] = ...
            TYPE_OTHER_NAME: typing.ClassVar[int] = ...
            TYPE_SHORT_NAME: typing.ClassVar[int] = ...

        class Im(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            CUSTOM_PROTOCOL: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            PROTOCOL: typing.ClassVar[str] = ...
            PROTOCOL_AIM: typing.ClassVar[int] = ...
            PROTOCOL_CUSTOM: typing.ClassVar[int] = ...
            PROTOCOL_GOOGLE_TALK: typing.ClassVar[int] = ...
            PROTOCOL_ICQ: typing.ClassVar[int] = ...
            PROTOCOL_JABBER: typing.ClassVar[int] = ...
            PROTOCOL_MSN: typing.ClassVar[int] = ...
            PROTOCOL_NETMEETING: typing.ClassVar[int] = ...
            PROTOCOL_QQ: typing.ClassVar[int] = ...
            PROTOCOL_SKYPE: typing.ClassVar[int] = ...
            PROTOCOL_YAHOO: typing.ClassVar[int] = ...
            TYPE_HOME: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            @staticmethod
            def getProtocolLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getProtocolLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Identity(ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            IDENTITY: typing.ClassVar[str] = ...
            NAMESPACE: typing.ClassVar[str] = ...

        class GroupMembership(ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            GROUP_ROW_ID: typing.ClassVar[str] = ...
            GROUP_SOURCE_ID: typing.ClassVar[str] = ...

        class Event(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            START_DATE: typing.ClassVar[str] = ...
            TYPE_ANNIVERSARY: typing.ClassVar[int] = ...
            TYPE_BIRTHDAY: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Email(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            ADDRESS: typing.ClassVar[str] = ...
            CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
            CONTENT_LOOKUP_URI: typing.ClassVar[android.net.Uri] = ...
            CONTENT_TYPE: typing.ClassVar[str] = ...
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DISPLAY_NAME: typing.ClassVar[str] = ...
            ENTERPRISE_CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            ENTERPRISE_CONTENT_LOOKUP_URI: typing.ClassVar[android.net.Uri] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            TYPE_HOME: typing.ClassVar[int] = ...
            TYPE_MOBILE: typing.ClassVar[int] = ...
            TYPE_OTHER: typing.ClassVar[int] = ...
            TYPE_WORK: typing.ClassVar[int] = ...
            @staticmethod
            def getTypeLabel(res: android.content.res.Resources, type: int | java.jint | java.lang.Integer, label: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
            @staticmethod
            def getTypeLabelResource(type: int | java.jint | java.lang.Integer, /) -> int: ...

        class Contactables(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            VISIBLE_CONTACTS_ONLY: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...

        class CommonColumns(ContactsContract.CommonDataKinds.BaseTypes):
            DATA: typing.ClassVar[str] = ...
            LABEL: typing.ClassVar[str] = ...
            TYPE: typing.ClassVar[str] = ...

        class Callable(ContactsContract.CommonDataKinds.CommonColumns, ContactsContract.DataColumnsWithJoins):
            CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            ENTERPRISE_CONTENT_FILTER_URI: typing.ClassVar[android.net.Uri] = ...
            EXTRA_ADDRESS_BOOK_INDEX: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_COUNTS: typing.ClassVar[str] = ...
            EXTRA_ADDRESS_BOOK_INDEX_TITLES: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...

        class BaseTypes(java.lang.Object):
            TYPE_CUSTOM: typing.ClassVar[int] = ...

    class BaseSyncColumns(java.lang.Object):
        SYNC1: typing.ClassVar[str] = ...
        SYNC2: typing.ClassVar[str] = ...
        SYNC3: typing.ClassVar[str] = ...
        SYNC4: typing.ClassVar[str] = ...

    class AggregationExceptions(BaseColumns):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        RAW_CONTACT_ID1: typing.ClassVar[str] = ...
        RAW_CONTACT_ID2: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...
        TYPE_AUTOMATIC: typing.ClassVar[int] = ...
        TYPE_KEEP_SEPARATE: typing.ClassVar[int] = ...
        TYPE_KEEP_TOGETHER: typing.ClassVar[int] = ...

class DocumentsContract(java.lang.Object):
    ACTION_DOCUMENT_SETTINGS: typing.ClassVar[str] = ...
    EXTRA_ERROR: typing.ClassVar[str] = ...
    EXTRA_EXCLUDE_SELF: typing.ClassVar[str] = ...
    EXTRA_INFO: typing.ClassVar[str] = ...
    EXTRA_INITIAL_URI: typing.ClassVar[str] = ...
    EXTRA_LOADING: typing.ClassVar[str] = ...
    EXTRA_ORIENTATION: typing.ClassVar[str] = ...
    EXTRA_PROMPT: typing.ClassVar[str] = ...
    METADATA_EXIF: typing.ClassVar[str] = ...
    METADATA_TREE_COUNT: typing.ClassVar[str] = ...
    METADATA_TREE_SIZE: typing.ClassVar[str] = ...
    METADATA_TYPES: typing.ClassVar[str] = ...
    PROVIDER_INTERFACE: typing.ClassVar[str] = ...
    QUERY_ARG_DISPLAY_NAME: typing.ClassVar[str] = ...
    QUERY_ARG_EXCLUDE_MEDIA: typing.ClassVar[str] = ...
    QUERY_ARG_FILE_SIZE_OVER: typing.ClassVar[str] = ...
    QUERY_ARG_LAST_MODIFIED_AFTER: typing.ClassVar[str] = ...
    QUERY_ARG_MIME_TYPES: typing.ClassVar[str] = ...
    @staticmethod
    def buildChildDocumentsUri(authority: str | java.lang.String, parentDocumentId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildChildDocumentsUriUsingTree(treeUri: android.net.Uri, parentDocumentId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildDocumentUri(authority: str | java.lang.String, documentId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildDocumentUriUsingTree(treeUri: android.net.Uri, documentId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildRecentDocumentsUri(authority: str | java.lang.String, rootId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildRootUri(authority: str | java.lang.String, rootId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildRootsUri(authority: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildSearchDocumentsUri(authority: str | java.lang.String, rootId: str | java.lang.String, query: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildTreeDocumentUri(authority: str | java.lang.String, documentId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def copyDocument(content: android.content.ContentResolver, sourceDocumentUri: android.net.Uri, targetParentDocumentUri: android.net.Uri, /) -> android.net.Uri | None: ...
    @staticmethod
    def createDocument(content: android.content.ContentResolver, parentDocumentUri: android.net.Uri, mimeType: str | java.lang.String, displayName: str | java.lang.String, /) -> android.net.Uri | None: ...
    @staticmethod
    def createWebLinkIntent(content: android.content.ContentResolver, uri: android.net.Uri, options: android.os.Bundle, /) -> android.content.IntentSender | None: ...
    @staticmethod
    def deleteDocument(content: android.content.ContentResolver, documentUri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def ejectRoot(content: android.content.ContentResolver, rootUri: android.net.Uri, /) -> None: ...
    @staticmethod
    def findDocumentPath(content: android.content.ContentResolver, treeUri: android.net.Uri, /) -> DocumentsContract.Path | None: ...
    @staticmethod
    def getDocumentId(documentUri: android.net.Uri, /) -> str: ...
    @staticmethod
    def getDocumentMetadata(content: android.content.ContentResolver, documentUri: android.net.Uri, /) -> android.os.Bundle | None: ...
    @staticmethod
    def getDocumentThumbnail(content: android.content.ContentResolver, documentUri: android.net.Uri, size: android.graphics.Point, signal: android.os.CancellationSignal, /) -> android.graphics.Bitmap | None: ...
    @staticmethod
    def getRootId(rootUri: android.net.Uri, /) -> str | None: ...
    @staticmethod
    def getSearchDocumentsQuery(searchDocumentsUri: android.net.Uri, /) -> str: ...
    @staticmethod
    def getTreeDocumentId(documentUri: android.net.Uri, /) -> str: ...
    @staticmethod
    def isChildDocument(content: android.content.ContentResolver, parentDocumentUri: android.net.Uri, childDocumentUri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isDocumentUri(context: android.content.Context, uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isRootUri(context: android.content.Context, uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isRootsUri(context: android.content.Context, uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isTreeUri(uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def moveDocument(content: android.content.ContentResolver, sourceDocumentUri: android.net.Uri, sourceParentDocumentUri: android.net.Uri, targetParentDocumentUri: android.net.Uri, /) -> android.net.Uri | None: ...
    @staticmethod
    def removeDocument(content: android.content.ContentResolver, documentUri: android.net.Uri, parentDocumentUri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def renameDocument(content: android.content.ContentResolver, documentUri: android.net.Uri, displayName: str | java.lang.String, /) -> android.net.Uri | None: ...

    class Root(java.lang.Object):
        COLUMN_AVAILABLE_BYTES: typing.ClassVar[str] = ...
        COLUMN_CAPACITY_BYTES: typing.ClassVar[str] = ...
        COLUMN_DOCUMENT_ID: typing.ClassVar[str] = ...
        COLUMN_FLAGS: typing.ClassVar[str] = ...
        COLUMN_ICON: typing.ClassVar[str] = ...
        COLUMN_MIME_TYPES: typing.ClassVar[str] = ...
        COLUMN_QUERY_ARGS: typing.ClassVar[str] = ...
        COLUMN_ROOT_ID: typing.ClassVar[str] = ...
        COLUMN_SUMMARY: typing.ClassVar[str] = ...
        COLUMN_TITLE: typing.ClassVar[str] = ...
        FLAG_EMPTY: typing.ClassVar[int] = ...
        FLAG_LOCAL_ONLY: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_CREATE: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_EJECT: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_IS_CHILD: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_RECENTS: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_SEARCH: typing.ClassVar[int] = ...
        MIME_TYPE_ITEM: typing.ClassVar[str] = ...

    class Path(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DocumentsContract.Path]] = ...
        def __init__(self, rootId: str | java.lang.String, path: java.util.List[java.lang.String], /) -> None: ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getPath(self) -> java.util.List[java.lang.String]: ...
        def getRootId(self) -> str: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Document(java.lang.Object):
        COLUMN_DISPLAY_NAME: typing.ClassVar[str] = ...
        COLUMN_DOCUMENT_ID: typing.ClassVar[str] = ...
        COLUMN_FLAGS: typing.ClassVar[str] = ...
        COLUMN_ICON: typing.ClassVar[str] = ...
        COLUMN_LAST_MODIFIED: typing.ClassVar[str] = ...
        COLUMN_MIME_TYPE: typing.ClassVar[str] = ...
        COLUMN_SIZE: typing.ClassVar[str] = ...
        COLUMN_SUMMARY: typing.ClassVar[str] = ...
        FLAG_DIR_BLOCKS_OPEN_DOCUMENT_TREE: typing.ClassVar[int] = ...
        FLAG_DIR_PREFERS_GRID: typing.ClassVar[int] = ...
        FLAG_DIR_PREFERS_LAST_MODIFIED: typing.ClassVar[int] = ...
        FLAG_DIR_SUPPORTS_CREATE: typing.ClassVar[int] = ...
        FLAG_PARTIAL: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_COPY: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_DELETE: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_METADATA: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_MOVE: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_REMOVE: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_RENAME: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_SETTINGS: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_THUMBNAIL: typing.ClassVar[int] = ...
        FLAG_SUPPORTS_WRITE: typing.ClassVar[int] = ...
        FLAG_VIRTUAL_DOCUMENT: typing.ClassVar[int] = ...
        FLAG_WEB_LINKABLE: typing.ClassVar[int] = ...
        MIME_TYPE_DIR: typing.ClassVar[str] = ...

class DocumentsProvider(android.content.ContentProvider):
    def __init__(self) -> None: ...
    def attachInfo(self, context: android.content.Context, info: android.content.pm.ProviderInfo, /) -> None: ...
    def call(self, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle: ...
    def canonicalize(self, uri: android.net.Uri, /) -> android.net.Uri: ...
    def copyDocument(self, sourceDocumentId: str | java.lang.String, targetParentDocumentId: str | java.lang.String, /) -> str: ...
    def createDocument(self, parentDocumentId: str | java.lang.String, mimeType: str | java.lang.String, displayName: str | java.lang.String, /) -> str: ...
    def createWebLinkIntent(self, documentId: str | java.lang.String, options: android.os.Bundle, /) -> android.content.IntentSender: ...
    def delete(self, uri: android.net.Uri, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def deleteDocument(self, documentId: str | java.lang.String, /) -> None: ...
    def ejectRoot(self, rootId: str | java.lang.String, /) -> None: ...
    def findDocumentPath(self, parentDocumentId: str | java.lang.String, childDocumentId: str | java.lang.String, /) -> DocumentsContract.Path: ...
    def getDocumentMetadata(self, documentId: str | java.lang.String, /) -> android.os.Bundle | None: ...
    def getDocumentStreamTypes(self, documentId: str | java.lang.String, mimeTypeFilter: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getDocumentType(self, documentId: str | java.lang.String, /) -> str: ...
    def getStreamTypes(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getType(self, uri: android.net.Uri, /) -> str: ...
    def getTypeAnonymous(self, uri: android.net.Uri, /) -> str | None: ...
    def insert(self, uri: android.net.Uri, values: android.content.ContentValues, /) -> android.net.Uri: ...
    def isChildDocument(self, parentDocumentId: str | java.lang.String, documentId: str | java.lang.String, /) -> bool: ...
    def moveDocument(self, sourceDocumentId: str | java.lang.String, sourceParentDocumentId: str | java.lang.String, targetParentDocumentId: str | java.lang.String, /) -> str: ...
    @typing.overload
    def openAssetFile(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.content.res.AssetFileDescriptor: ...
    @typing.overload
    def openAssetFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    def openDocument(self, arg1: str | java.lang.String, arg2: str | java.lang.String, arg3: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor: ...
    def openDocumentThumbnail(self, documentId: str | java.lang.String, sizeHint: android.graphics.Point, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    @typing.overload
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.os.ParcelFileDescriptor: ...
    @typing.overload
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor: ...
    @typing.overload
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, /) -> android.content.res.AssetFileDescriptor: ...
    @typing.overload
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    def openTypedDocument(self, documentId: str | java.lang.String, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def queryChildDocuments(self, parentDocumentId: str | java.lang.String, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, /) -> android.database.Cursor: ...
    @typing.overload
    def queryChildDocuments(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArray[java.lang.String], arg3: str | java.lang.String, /) -> android.database.Cursor: ...
    def queryDocument(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
    @typing.overload
    def queryRecentDocuments(self, rootId: str | java.lang.String, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor | None: ...
    @typing.overload
    def queryRecentDocuments(self, rootId: str | java.lang.String, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    def queryRoots(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
    @typing.overload
    def querySearchDocuments(self, rootId: str | java.lang.String, query: str | java.lang.String, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor | None: ...
    @typing.overload
    def querySearchDocuments(self, rootId: str | java.lang.String, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, /) -> android.database.Cursor | None: ...
    def removeDocument(self, documentId: str | java.lang.String, parentDocumentId: str | java.lang.String, /) -> None: ...
    def renameDocument(self, documentId: str | java.lang.String, displayName: str | java.lang.String, /) -> str: ...
    def revokeDocumentPermission(self, documentId: str | java.lang.String, /) -> None: ...
    def update(self, uri: android.net.Uri, values: android.content.ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...

class E2eeContactKeysManager(java.lang.Object):
    VERIFICATION_STATE_UNVERIFIED: typing.ClassVar[int] = ...
    VERIFICATION_STATE_VERIFICATION_FAILED: typing.ClassVar[int] = ...
    VERIFICATION_STATE_VERIFIED: typing.ClassVar[int] = ...
    def getAllE2eeContactKeys(self, lookupKey: str | java.lang.String, /) -> java.util.List[E2eeContactKeysManager.E2eeContactKey]: ...
    def getAllE2eeSelfKeys(self) -> java.util.List[E2eeContactKeysManager.E2eeSelfKey]: ...
    def getE2eeContactKey(self, lookupKey: str | java.lang.String, deviceId: str | java.lang.String, accountId: str | java.lang.String, /) -> E2eeContactKeysManager.E2eeContactKey | None: ...
    def getE2eeSelfKey(self, deviceId: str | java.lang.String, accountId: str | java.lang.String, /) -> E2eeContactKeysManager.E2eeSelfKey | None: ...
    @staticmethod
    def getMaxKeySizeBytes() -> int: ...
    def getOwnerE2eeContactKeys(self, lookupKey: str | java.lang.String, /) -> java.util.List[E2eeContactKeysManager.E2eeContactKey]: ...
    def getOwnerE2eeSelfKeys(self) -> java.util.List[E2eeContactKeysManager.E2eeSelfKey]: ...
    def removeE2eeContactKey(self, lookupKey: str | java.lang.String, deviceId: str | java.lang.String, accountId: str | java.lang.String, /) -> bool: ...
    def removeE2eeSelfKey(self, deviceId: str | java.lang.String, accountId: str | java.lang.String, /) -> bool: ...
    def updateE2eeContactKeyLocalVerificationState(self, lookupKey: str | java.lang.String, deviceId: str | java.lang.String, accountId: str | java.lang.String, localVerificationState: int | java.jint | java.lang.Integer, /) -> bool: ...
    def updateE2eeContactKeyRemoteVerificationState(self, lookupKey: str | java.lang.String, deviceId: str | java.lang.String, accountId: str | java.lang.String, remoteVerificationState: int | java.jint | java.lang.Integer, /) -> bool: ...
    def updateE2eeSelfKeyRemoteVerificationState(self, deviceId: str | java.lang.String, accountId: str | java.lang.String, remoteVerificationState: int | java.jint | java.lang.Integer, /) -> bool: ...
    def updateOrInsertE2eeContactKey(self, lookupKey: str | java.lang.String, deviceId: str | java.lang.String, accountId: str | java.lang.String, keyValue: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def updateOrInsertE2eeSelfKey(self, deviceId: str | java.lang.String, accountId: str | java.lang.String, keyValue: java.chaquopy.JavaArrayJByte, /) -> bool: ...

    class E2eeSelfKey(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[E2eeContactKeysManager.E2eeSelfKey]] = ...
        def describeContents(self) -> int: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAccountId(self) -> str: ...
        def getDeviceId(self) -> str: ...
        def getKeyValue(self) -> java.chaquopy.JavaArrayJByte: ...
        def getOwnerPackageName(self) -> str: ...
        def getRemoteVerificationState(self) -> int: ...
        def getTimeUpdated(self) -> int: ...
        def hashCode(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class E2eeContactKey(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[E2eeContactKeysManager.E2eeContactKey]] = ...
        def describeContents(self) -> int: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAccountId(self) -> str: ...
        def getDeviceId(self) -> str: ...
        def getDisplayName(self) -> str: ...
        def getEmailAddress(self) -> str: ...
        def getKeyValue(self) -> java.chaquopy.JavaArrayJByte: ...
        def getLocalVerificationState(self) -> int: ...
        def getOwnerPackageName(self) -> str: ...
        def getPhoneNumber(self) -> str: ...
        def getRemoteVerificationState(self) -> int: ...
        def getTimeUpdated(self) -> int: ...
        def hashCode(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FontRequest(java.lang.Object):
    @typing.overload
    def __init__(self, providerAuthority: str | java.lang.String, providerPackage: str | java.lang.String, query: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, providerAuthority: str | java.lang.String, providerPackage: str | java.lang.String, query: str | java.lang.String, certificates: java.util.List[java.util.List[java.chaquopy.JavaArrayJByte]], /) -> None: ...
    def getCertificates(self) -> java.util.List[java.util.List[java.chaquopy.JavaArrayJByte]]: ...
    def getProviderAuthority(self) -> str: ...
    def getProviderPackage(self) -> str: ...
    def getQuery(self) -> str: ...
    def toString(self) -> str: ...

class FontsContract(java.lang.Object):
    @staticmethod
    def buildTypeface(context: android.content.Context, cancellationSignal: android.os.CancellationSignal, fonts: java.chaquopy.JavaArray[FontsContract.FontInfo], /) -> android.graphics.Typeface | None: ...
    @staticmethod
    def fetchFonts(context: android.content.Context, cancellationSignal: android.os.CancellationSignal, request: FontRequest, /) -> FontsContract.FontFamilyResult: ...
    @staticmethod
    def requestFonts(context: android.content.Context, request: FontRequest, handler: android.os.Handler, cancellationSignal: android.os.CancellationSignal, callback: FontsContract.FontRequestCallback, /) -> None: ...

    class FontRequestCallback(java.lang.Object):
        FAIL_REASON_FONT_LOAD_ERROR: typing.ClassVar[int] = ...
        FAIL_REASON_FONT_NOT_FOUND: typing.ClassVar[int] = ...
        FAIL_REASON_FONT_UNAVAILABLE: typing.ClassVar[int] = ...
        FAIL_REASON_MALFORMED_QUERY: typing.ClassVar[int] = ...
        FAIL_REASON_PROVIDER_NOT_FOUND: typing.ClassVar[int] = ...
        FAIL_REASON_WRONG_CERTIFICATES: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def onTypefaceRequestFailed(self, reason: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTypefaceRetrieved(self, typeface: android.graphics.Typeface, /) -> None: ...

    class FontInfo(java.lang.Object):
        def getAxes(self) -> java.chaquopy.JavaArray[android.graphics.fonts.FontVariationAxis]: ...
        def getResultCode(self) -> int: ...
        def getTtcIndex(self) -> int: ...
        def getUri(self) -> android.net.Uri: ...
        def getWeight(self) -> int: ...
        def isItalic(self) -> bool: ...

    class FontFamilyResult(java.lang.Object):
        STATUS_OK: typing.ClassVar[int] = ...
        STATUS_REJECTED: typing.ClassVar[int] = ...
        STATUS_UNEXPECTED_DATA_PROVIDED: typing.ClassVar[int] = ...
        STATUS_WRONG_CERTIFICATES: typing.ClassVar[int] = ...
        def getFonts(self) -> java.chaquopy.JavaArray[FontsContract.FontInfo]: ...
        def getStatusCode(self) -> int: ...

    class Columns(BaseColumns):
        FILE_ID: typing.ClassVar[str] = ...
        ITALIC: typing.ClassVar[str] = ...
        RESULT_CODE: typing.ClassVar[str] = ...
        RESULT_CODE_FONT_NOT_FOUND: typing.ClassVar[int] = ...
        RESULT_CODE_FONT_UNAVAILABLE: typing.ClassVar[int] = ...
        RESULT_CODE_MALFORMED_QUERY: typing.ClassVar[int] = ...
        RESULT_CODE_OK: typing.ClassVar[int] = ...
        TTC_INDEX: typing.ClassVar[str] = ...
        VARIATION_SETTINGS: typing.ClassVar[str] = ...
        WEIGHT: typing.ClassVar[str] = ...

class LiveFolders(BaseColumns):
    ACTION_CREATE_LIVE_FOLDER: typing.ClassVar[str] = ...
    DESCRIPTION: typing.ClassVar[str] = ...
    DISPLAY_MODE_GRID: typing.ClassVar[int] = ...
    DISPLAY_MODE_LIST: typing.ClassVar[int] = ...
    EXTRA_LIVE_FOLDER_BASE_INTENT: typing.ClassVar[str] = ...
    EXTRA_LIVE_FOLDER_DISPLAY_MODE: typing.ClassVar[str] = ...
    EXTRA_LIVE_FOLDER_ICON: typing.ClassVar[str] = ...
    EXTRA_LIVE_FOLDER_NAME: typing.ClassVar[str] = ...
    ICON_BITMAP: typing.ClassVar[str] = ...
    ICON_PACKAGE: typing.ClassVar[str] = ...
    ICON_RESOURCE: typing.ClassVar[str] = ...
    INTENT: typing.ClassVar[str] = ...
    NAME: typing.ClassVar[str] = ...

class MediaStore(java.lang.Object):
    ACCESS_MEDIA_OWNER_PACKAGE_NAME_PERMISSION: typing.ClassVar[str] = ...
    ACCESS_OEM_METADATA_PERMISSION: typing.ClassVar[str] = ...
    ACTION_IMAGE_CAPTURE: typing.ClassVar[str] = ...
    ACTION_IMAGE_CAPTURE_SECURE: typing.ClassVar[str] = ...
    ACTION_MOTION_PHOTO_CAPTURE: typing.ClassVar[str] = ...
    ACTION_MOTION_PHOTO_CAPTURE_SECURE: typing.ClassVar[str] = ...
    ACTION_PICK_IMAGES: typing.ClassVar[str] = ...
    ACTION_PICK_IMAGES_SETTINGS: typing.ClassVar[str] = ...
    ACTION_REVIEW: typing.ClassVar[str] = ...
    ACTION_REVIEW_SECURE: typing.ClassVar[str] = ...
    ACTION_VIDEO_CAPTURE: typing.ClassVar[str] = ...
    AUTHORITY: typing.ClassVar[str] = ...
    AUTHORITY_URI: typing.ClassVar[android.net.Uri] = ...
    EXTRA_ACCEPT_ORIGINAL_MEDIA_FORMAT: typing.ClassVar[str] = ...
    EXTRA_BRIGHTNESS: typing.ClassVar[str] = ...
    EXTRA_DURATION_LIMIT: typing.ClassVar[str] = ...
    EXTRA_FINISH_ON_COMPLETION: typing.ClassVar[str] = ...
    EXTRA_FULL_SCREEN: typing.ClassVar[str] = ...
    EXTRA_MEDIA_ALBUM: typing.ClassVar[str] = ...
    EXTRA_MEDIA_ARTIST: typing.ClassVar[str] = ...
    EXTRA_MEDIA_CAPABILITIES: typing.ClassVar[str] = ...
    EXTRA_MEDIA_CAPABILITIES_UID: typing.ClassVar[str] = ...
    EXTRA_MEDIA_FOCUS: typing.ClassVar[str] = ...
    EXTRA_MEDIA_GENRE: typing.ClassVar[str] = ...
    EXTRA_MEDIA_PLAYLIST: typing.ClassVar[str] = ...
    EXTRA_MEDIA_RADIO_CHANNEL: typing.ClassVar[str] = ...
    EXTRA_MEDIA_TITLE: typing.ClassVar[str] = ...
    EXTRA_OUTPUT: typing.ClassVar[str] = ...
    EXTRA_PICKER_PRE_SELECTION_URIS: typing.ClassVar[str] = ...
    EXTRA_PICK_IMAGES_ACCENT_COLOR: typing.ClassVar[str] = ...
    EXTRA_PICK_IMAGES_IN_ORDER: typing.ClassVar[str] = ...
    EXTRA_PICK_IMAGES_LAUNCH_TAB: typing.ClassVar[str] = ...
    EXTRA_PICK_IMAGES_MAX: typing.ClassVar[str] = ...
    EXTRA_SCREEN_ORIENTATION: typing.ClassVar[str] = ...
    EXTRA_SHOW_ACTION_ICONS: typing.ClassVar[str] = ...
    EXTRA_SIZE_LIMIT: typing.ClassVar[str] = ...
    EXTRA_VIDEO_QUALITY: typing.ClassVar[str] = ...
    INTENT_ACTION_MEDIA_PLAY_FROM_SEARCH: typing.ClassVar[str] = ...
    INTENT_ACTION_MEDIA_SEARCH: typing.ClassVar[str] = ...
    INTENT_ACTION_MUSIC_PLAYER: typing.ClassVar[str] = ...
    INTENT_ACTION_STILL_IMAGE_CAMERA: typing.ClassVar[str] = ...
    INTENT_ACTION_STILL_IMAGE_CAMERA_SECURE: typing.ClassVar[str] = ...
    INTENT_ACTION_TEXT_OPEN_FROM_SEARCH: typing.ClassVar[str] = ...
    INTENT_ACTION_VIDEO_CAMERA: typing.ClassVar[str] = ...
    INTENT_ACTION_VIDEO_PLAY_FROM_SEARCH: typing.ClassVar[str] = ...
    MATCH_DEFAULT: typing.ClassVar[int] = ...
    MATCH_EXCLUDE: typing.ClassVar[int] = ...
    MATCH_INCLUDE: typing.ClassVar[int] = ...
    MATCH_ONLY: typing.ClassVar[int] = ...
    MEDIA_IGNORE_FILENAME: typing.ClassVar[str] = ...
    MEDIA_SCANNER_VOLUME: typing.ClassVar[str] = ...
    META_DATA_REVIEW_GALLERY_PREWARM_SERVICE: typing.ClassVar[str] = ...
    META_DATA_STILL_IMAGE_CAMERA_PREWARM_SERVICE: typing.ClassVar[str] = ...
    PICK_IMAGES_TAB_ALBUMS: typing.ClassVar[int] = ...
    PICK_IMAGES_TAB_IMAGES: typing.ClassVar[int] = ...
    QUERY_ARG_INCLUDE_RECENTLY_UNMOUNTED_VOLUMES: typing.ClassVar[str] = ...
    QUERY_ARG_LATEST_SELECTION_ONLY: typing.ClassVar[str] = ...
    QUERY_ARG_MATCH_FAVORITE: typing.ClassVar[str] = ...
    QUERY_ARG_MATCH_PENDING: typing.ClassVar[str] = ...
    QUERY_ARG_MATCH_TRASHED: typing.ClassVar[str] = ...
    QUERY_ARG_MEDIA_STANDARD_SORT_ORDER: typing.ClassVar[str] = ...
    QUERY_ARG_RELATED_URI: typing.ClassVar[str] = ...
    UNKNOWN_STRING: typing.ClassVar[str] = ...
    VOLUME_EXTERNAL: typing.ClassVar[str] = ...
    VOLUME_EXTERNAL_PRIMARY: typing.ClassVar[str] = ...
    VOLUME_INTERNAL: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def canManageMedia(context: android.content.Context, /) -> bool: ...
    @staticmethod
    def createDeleteRequest(resolver: android.content.ContentResolver, uris: java.util.Collection[android.net.Uri], /) -> android.app.PendingIntent: ...
    @staticmethod
    def createFavoriteRequest(resolver: android.content.ContentResolver, uris: java.util.Collection[android.net.Uri], value: bool | java.jboolean | java.lang.Boolean, /) -> android.app.PendingIntent: ...
    @staticmethod
    def createTrashRequest(resolver: android.content.ContentResolver, uris: java.util.Collection[android.net.Uri], value: bool | java.jboolean | java.lang.Boolean, /) -> android.app.PendingIntent: ...
    @staticmethod
    def createWriteRequest(resolver: android.content.ContentResolver, uris: java.util.Collection[android.net.Uri], /) -> android.app.PendingIntent: ...
    @staticmethod
    def getDocumentUri(context: android.content.Context, mediaUri: android.net.Uri, /) -> android.net.Uri | None: ...
    @staticmethod
    def getExternalVolumeNames(context: android.content.Context, /) -> java.util.Set[java.lang.String]: ...
    @staticmethod
    def getGeneration(context: android.content.Context, volumeName: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getMediaScannerUri() -> android.net.Uri: ...
    @staticmethod
    def getMediaUri(context: android.content.Context, documentUri: android.net.Uri, /) -> android.net.Uri | None: ...
    @staticmethod
    def getOriginalMediaFormatFileDescriptor(context: android.content.Context, fileDescriptor: android.os.ParcelFileDescriptor, /) -> android.os.ParcelFileDescriptor: ...
    @staticmethod
    def getPickImagesMaxLimit() -> int: ...
    @staticmethod
    def getRecentExternalVolumeNames(context: android.content.Context, /) -> java.util.Set[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def getRedactedUri(resolver: android.content.ContentResolver, uri: android.net.Uri, /) -> android.net.Uri | None: ...
    @typing.overload
    @staticmethod
    def getRedactedUri(resolver: android.content.ContentResolver, uris: java.util.List[android.net.Uri], /) -> java.util.List[android.net.Uri] | None: ...
    @staticmethod
    def getRequireOriginal(uri: android.net.Uri, /) -> bool: ...
    @typing.overload
    @staticmethod
    def getVersion(context: android.content.Context, /) -> str: ...
    @typing.overload
    @staticmethod
    def getVersion(context: android.content.Context, volumeName: str | java.lang.String, /) -> str: ...
    @staticmethod
    def getVolumeName(uri: android.net.Uri, /) -> str: ...
    @staticmethod
    def isCurrentCloudMediaProviderAuthority(resolver: android.content.ContentResolver, authority: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isCurrentSystemGallery(resolver: android.content.ContentResolver, uid: int | java.jint | java.lang.Integer, packageName: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isSupportedCloudMediaProviderAuthority(resolver: android.content.ContentResolver, authority: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def markIsFavoriteStatus(resolver: android.content.ContentResolver, uris: java.util.Collection[android.net.Uri], areFavorites: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def notifyCloudMediaChangedEvent(resolver: android.content.ContentResolver, authority: str | java.lang.String, currentMediaCollectionId: str | java.lang.String, /) -> None: ...
    @staticmethod
    def openAssetFileDescriptor(resolver: android.content.ContentResolver, uri: android.net.Uri, mode: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    @staticmethod
    def openFileDescriptor(resolver: android.content.ContentResolver, uri: android.net.Uri, mode: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor: ...
    @staticmethod
    def openTypedAssetFileDescriptor(resolver: android.content.ContentResolver, uri: android.net.Uri, mimeType: str | java.lang.String, opts: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor: ...
    @staticmethod
    def setIncludePending(uri: android.net.Uri, /) -> android.net.Uri: ...
    @staticmethod
    def setRequireOriginal(uri: android.net.Uri, /) -> android.net.Uri: ...

    class Video(java.lang.Object):
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @staticmethod
        def query(cr: android.content.ContentResolver, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...

        class VideoColumns(MediaStore.MediaColumns):
            BOOKMARK: typing.ClassVar[str] = ...
            CATEGORY: typing.ClassVar[str] = ...
            COLOR_RANGE: typing.ClassVar[str] = ...
            COLOR_STANDARD: typing.ClassVar[str] = ...
            COLOR_TRANSFER: typing.ClassVar[str] = ...
            DESCRIPTION: typing.ClassVar[str] = ...
            IS_PRIVATE: typing.ClassVar[str] = ...
            LANGUAGE: typing.ClassVar[str] = ...
            LATITUDE: typing.ClassVar[str] = ...
            LONGITUDE: typing.ClassVar[str] = ...
            MINI_THUMB_MAGIC: typing.ClassVar[str] = ...
            TAGS: typing.ClassVar[str] = ...

        class Thumbnails(BaseColumns):
            DATA: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            FULL_SCREEN_KIND: typing.ClassVar[int] = ...
            HEIGHT: typing.ClassVar[str] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            KIND: typing.ClassVar[str] = ...
            MICRO_KIND: typing.ClassVar[int] = ...
            MINI_KIND: typing.ClassVar[int] = ...
            VIDEO_ID: typing.ClassVar[str] = ...
            WIDTH: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...
            @typing.overload
            @staticmethod
            def cancelThumbnailRequest(cr: android.content.ContentResolver, origId: int | java.jlong | java.lang.Long, /) -> None: ...
            @typing.overload
            @staticmethod
            def cancelThumbnailRequest(cr: android.content.ContentResolver, videoId: int | java.jlong | java.lang.Long, groupId: int | java.jlong | java.lang.Long, /) -> None: ...
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
            @staticmethod
            def getKindSize(kind: int | java.jint | java.lang.Integer, /) -> android.util.Size: ...
            @typing.overload
            @staticmethod
            def getThumbnail(cr: android.content.ContentResolver, videoId: int | java.jlong | java.lang.Long, kind: int | java.jint | java.lang.Integer, options: android.graphics.BitmapFactory.Options, /) -> android.graphics.Bitmap: ...
            @typing.overload
            @staticmethod
            def getThumbnail(cr: android.content.ContentResolver, videoId: int | java.jlong | java.lang.Long, groupId: int | java.jlong | java.lang.Long, kind: int | java.jint | java.lang.Integer, options: android.graphics.BitmapFactory.Options, /) -> android.graphics.Bitmap: ...

        class Media(MediaStore.Video.VideoColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            def __init__(self) -> None: ...
            @typing.overload
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
            @typing.overload
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...

    class PickerMediaColumns(java.lang.Object):
        DATA: typing.ClassVar[str] = ...
        DATE_TAKEN: typing.ClassVar[str] = ...
        DISPLAY_NAME: typing.ClassVar[str] = ...
        DURATION_MILLIS: typing.ClassVar[str] = ...
        HEIGHT: typing.ClassVar[str] = ...
        MIME_TYPE: typing.ClassVar[str] = ...
        ORIENTATION: typing.ClassVar[str] = ...
        SIZE: typing.ClassVar[str] = ...
        WIDTH: typing.ClassVar[str] = ...

    class MediaColumns(BaseColumns):
        ALBUM: typing.ClassVar[str] = ...
        ALBUM_ARTIST: typing.ClassVar[str] = ...
        ARTIST: typing.ClassVar[str] = ...
        AUTHOR: typing.ClassVar[str] = ...
        BITRATE: typing.ClassVar[str] = ...
        BUCKET_DISPLAY_NAME: typing.ClassVar[str] = ...
        BUCKET_ID: typing.ClassVar[str] = ...
        CAPTURE_FRAMERATE: typing.ClassVar[str] = ...
        CD_TRACK_NUMBER: typing.ClassVar[str] = ...
        COMPILATION: typing.ClassVar[str] = ...
        COMPOSER: typing.ClassVar[str] = ...
        DATA: typing.ClassVar[str] = ...
        DATE_ADDED: typing.ClassVar[str] = ...
        DATE_EXPIRES: typing.ClassVar[str] = ...
        DATE_MODIFIED: typing.ClassVar[str] = ...
        DATE_TAKEN: typing.ClassVar[str] = ...
        DISC_NUMBER: typing.ClassVar[str] = ...
        DISPLAY_NAME: typing.ClassVar[str] = ...
        DOCUMENT_ID: typing.ClassVar[str] = ...
        DURATION: typing.ClassVar[str] = ...
        GENERATION_ADDED: typing.ClassVar[str] = ...
        GENERATION_MODIFIED: typing.ClassVar[str] = ...
        GENRE: typing.ClassVar[str] = ...
        HEIGHT: typing.ClassVar[str] = ...
        INFERRED_DATE: typing.ClassVar[str] = ...
        INSTANCE_ID: typing.ClassVar[str] = ...
        IS_DOWNLOAD: typing.ClassVar[str] = ...
        IS_DRM: typing.ClassVar[str] = ...
        IS_FAVORITE: typing.ClassVar[str] = ...
        IS_PENDING: typing.ClassVar[str] = ...
        IS_TRASHED: typing.ClassVar[str] = ...
        MIME_TYPE: typing.ClassVar[str] = ...
        NUM_TRACKS: typing.ClassVar[str] = ...
        OEM_METADATA: typing.ClassVar[str] = ...
        ORIENTATION: typing.ClassVar[str] = ...
        ORIGINAL_DOCUMENT_ID: typing.ClassVar[str] = ...
        OWNER_PACKAGE_NAME: typing.ClassVar[str] = ...
        RELATIVE_PATH: typing.ClassVar[str] = ...
        RESOLUTION: typing.ClassVar[str] = ...
        SIZE: typing.ClassVar[str] = ...
        TITLE: typing.ClassVar[str] = ...
        VOLUME_NAME: typing.ClassVar[str] = ...
        WIDTH: typing.ClassVar[str] = ...
        WRITER: typing.ClassVar[str] = ...
        XMP: typing.ClassVar[str] = ...
        YEAR: typing.ClassVar[str] = ...

    class Images(java.lang.Object):
        def __init__(self) -> None: ...

        class Thumbnails(BaseColumns):
            DATA: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            FULL_SCREEN_KIND: typing.ClassVar[int] = ...
            HEIGHT: typing.ClassVar[str] = ...
            IMAGE_ID: typing.ClassVar[str] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            KIND: typing.ClassVar[str] = ...
            MICRO_KIND: typing.ClassVar[int] = ...
            MINI_KIND: typing.ClassVar[int] = ...
            THUMB_DATA: typing.ClassVar[str] = ...
            WIDTH: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...
            @typing.overload
            @staticmethod
            def cancelThumbnailRequest(cr: android.content.ContentResolver, origId: int | java.jlong | java.lang.Long, /) -> None: ...
            @typing.overload
            @staticmethod
            def cancelThumbnailRequest(cr: android.content.ContentResolver, origId: int | java.jlong | java.lang.Long, groupId: int | java.jlong | java.lang.Long, /) -> None: ...
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
            @staticmethod
            def getKindSize(kind: int | java.jint | java.lang.Integer, /) -> android.util.Size: ...
            @typing.overload
            @staticmethod
            def getThumbnail(cr: android.content.ContentResolver, imageId: int | java.jlong | java.lang.Long, kind: int | java.jint | java.lang.Integer, options: android.graphics.BitmapFactory.Options, /) -> android.graphics.Bitmap: ...
            @typing.overload
            @staticmethod
            def getThumbnail(cr: android.content.ContentResolver, imageId: int | java.jlong | java.lang.Long, groupId: int | java.jlong | java.lang.Long, kind: int | java.jint | java.lang.Integer, options: android.graphics.BitmapFactory.Options, /) -> android.graphics.Bitmap: ...
            @staticmethod
            def query(cr: android.content.ContentResolver, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
            @staticmethod
            def queryMiniThumbnail(cr: android.content.ContentResolver, origId: int | java.jlong | java.lang.Long, kind: int | java.jint | java.lang.Integer, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
            @staticmethod
            def queryMiniThumbnails(cr: android.content.ContentResolver, uri: android.net.Uri, kind: int | java.jint | java.lang.Integer, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...

        class Media(MediaStore.Images.ImageColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            def __init__(self) -> None: ...
            @staticmethod
            def getBitmap(cr: android.content.ContentResolver, url: android.net.Uri, /) -> android.graphics.Bitmap: ...
            @typing.overload
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
            @typing.overload
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
            @typing.overload
            @staticmethod
            def insertImage(cr: android.content.ContentResolver, source: android.graphics.Bitmap, title: str | java.lang.String, description: str | java.lang.String, /) -> str: ...
            @typing.overload
            @staticmethod
            def insertImage(cr: android.content.ContentResolver, imagePath: str | java.lang.String, name: str | java.lang.String, description: str | java.lang.String, /) -> str: ...
            @typing.overload
            @staticmethod
            def query(cr: android.content.ContentResolver, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
            @typing.overload
            @staticmethod
            def query(cr: android.content.ContentResolver, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], where: str | java.lang.String, orderBy: str | java.lang.String, /) -> android.database.Cursor: ...
            @typing.overload
            @staticmethod
            def query(cr: android.content.ContentResolver, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], orderBy: str | java.lang.String, /) -> android.database.Cursor: ...

        class ImageColumns(MediaStore.MediaColumns):
            DESCRIPTION: typing.ClassVar[str] = ...
            EXPOSURE_TIME: typing.ClassVar[str] = ...
            F_NUMBER: typing.ClassVar[str] = ...
            ISO: typing.ClassVar[str] = ...
            IS_PRIVATE: typing.ClassVar[str] = ...
            LATITUDE: typing.ClassVar[str] = ...
            LONGITUDE: typing.ClassVar[str] = ...
            MINI_THUMB_MAGIC: typing.ClassVar[str] = ...
            PICASA_ID: typing.ClassVar[str] = ...
            SCENE_CAPTURE_TYPE: typing.ClassVar[str] = ...

    class Files(java.lang.Object):
        def __init__(self) -> None: ...
        @typing.overload
        @staticmethod
        def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
        @typing.overload
        @staticmethod
        def getContentUri(volumeName: str | java.lang.String, rowId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...

        class FileColumns(MediaStore.MediaColumns):
            MEDIA_TYPE: typing.ClassVar[str] = ...
            MEDIA_TYPE_AUDIO: typing.ClassVar[int] = ...
            MEDIA_TYPE_DOCUMENT: typing.ClassVar[int] = ...
            MEDIA_TYPE_IMAGE: typing.ClassVar[int] = ...
            MEDIA_TYPE_NONE: typing.ClassVar[int] = ...
            MEDIA_TYPE_PLAYLIST: typing.ClassVar[int] = ...
            MEDIA_TYPE_SUBTITLE: typing.ClassVar[int] = ...
            MEDIA_TYPE_VIDEO: typing.ClassVar[int] = ...
            MIME_TYPE: typing.ClassVar[str] = ...
            PARENT: typing.ClassVar[str] = ...

    class Downloads(MediaStore.DownloadColumns):
        CONTENT_TYPE: typing.ClassVar[str] = ...
        EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        @typing.overload
        @staticmethod
        def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
        @typing.overload
        @staticmethod
        def getContentUri(volumeName: str | java.lang.String, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...

    class DownloadColumns(MediaStore.MediaColumns):
        DOWNLOAD_URI: typing.ClassVar[str] = ...
        REFERER_URI: typing.ClassVar[str] = ...

    class Audio(java.lang.Object):
        def __init__(self) -> None: ...
        @staticmethod
        def keyFor(name: str | java.lang.String, /) -> str: ...

        class Radio(java.lang.Object):
            ENTRY_CONTENT_TYPE: typing.ClassVar[str] = ...

        class PlaylistsColumns(MediaStore.MediaColumns):
            DATA: typing.ClassVar[str] = ...
            DATE_ADDED: typing.ClassVar[str] = ...
            DATE_MODIFIED: typing.ClassVar[str] = ...
            NAME: typing.ClassVar[str] = ...

        class Playlists(MediaStore.Audio.PlaylistsColumns, BaseColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            ENTRY_CONTENT_TYPE: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            def __init__(self) -> None: ...
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...

            class Members(MediaStore.Audio.AudioColumns):
                AUDIO_ID: typing.ClassVar[str] = ...
                CONTENT_DIRECTORY: typing.ClassVar[str] = ...
                DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
                PLAYLIST_ID: typing.ClassVar[str] = ...
                PLAY_ORDER: typing.ClassVar[str] = ...
                _ID: typing.ClassVar[str] = ...
                def __init__(self) -> None: ...
                @staticmethod
                def getContentUri(volumeName: str | java.lang.String, playlistId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
                @staticmethod
                def moveItem(res: android.content.ContentResolver, playlistId: int | java.jlong | java.lang.Long, from_: int | java.jint | java.lang.Integer, to: int | java.jint | java.lang.Integer, /) -> bool: ...

        class Media(MediaStore.Audio.AudioColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            ENTRY_CONTENT_TYPE: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            EXTRA_MAX_BYTES: typing.ClassVar[str] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            RECORD_SOUND_ACTION: typing.ClassVar[str] = ...
            def __init__(self) -> None: ...
            @typing.overload
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
            @typing.overload
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
            @staticmethod
            def getContentUriForPath(path: str | java.lang.String, /) -> android.net.Uri: ...

        class GenresColumns(java.lang.Object):
            NAME: typing.ClassVar[str] = ...

        class Genres(BaseColumns, MediaStore.Audio.GenresColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            ENTRY_CONTENT_TYPE: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            def __init__(self) -> None: ...
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...
            @staticmethod
            def getContentUriForAudioId(volumeName: str | java.lang.String, audioId: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...

            class Members(MediaStore.Audio.AudioColumns):
                AUDIO_ID: typing.ClassVar[str] = ...
                CONTENT_DIRECTORY: typing.ClassVar[str] = ...
                DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
                GENRE_ID: typing.ClassVar[str] = ...
                def __init__(self) -> None: ...
                @staticmethod
                def getContentUri(volumeName: str | java.lang.String, genreId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...

        class AudioColumns(MediaStore.MediaColumns):
            ALBUM_ID: typing.ClassVar[str] = ...
            ALBUM_KEY: typing.ClassVar[str] = ...
            ARTIST_ID: typing.ClassVar[str] = ...
            ARTIST_KEY: typing.ClassVar[str] = ...
            BITS_PER_SAMPLE: typing.ClassVar[str] = ...
            BOOKMARK: typing.ClassVar[str] = ...
            GENRE: typing.ClassVar[str] = ...
            GENRE_ID: typing.ClassVar[str] = ...
            GENRE_KEY: typing.ClassVar[str] = ...
            IS_ALARM: typing.ClassVar[str] = ...
            IS_AUDIOBOOK: typing.ClassVar[str] = ...
            IS_MUSIC: typing.ClassVar[str] = ...
            IS_NOTIFICATION: typing.ClassVar[str] = ...
            IS_PODCAST: typing.ClassVar[str] = ...
            IS_RECORDING: typing.ClassVar[str] = ...
            IS_RINGTONE: typing.ClassVar[str] = ...
            SAMPLERATE: typing.ClassVar[str] = ...
            TITLE_KEY: typing.ClassVar[str] = ...
            TITLE_RESOURCE_URI: typing.ClassVar[str] = ...
            TRACK: typing.ClassVar[str] = ...
            YEAR: typing.ClassVar[str] = ...

        class Artists(BaseColumns, MediaStore.Audio.ArtistColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            ENTRY_CONTENT_TYPE: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            def __init__(self) -> None: ...
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...

            class Albums(BaseColumns, MediaStore.Audio.AlbumColumns):
                def __init__(self) -> None: ...
                @staticmethod
                def getContentUri(volumeName: str | java.lang.String, artistId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...

        class ArtistColumns(java.lang.Object):
            ARTIST: typing.ClassVar[str] = ...
            ARTIST_KEY: typing.ClassVar[str] = ...
            NUMBER_OF_ALBUMS: typing.ClassVar[str] = ...
            NUMBER_OF_TRACKS: typing.ClassVar[str] = ...

        class Albums(BaseColumns, MediaStore.Audio.AlbumColumns):
            CONTENT_TYPE: typing.ClassVar[str] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            ENTRY_CONTENT_TYPE: typing.ClassVar[str] = ...
            EXTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            INTERNAL_CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            def __init__(self) -> None: ...
            @staticmethod
            def getContentUri(volumeName: str | java.lang.String, /) -> android.net.Uri: ...

        class AlbumColumns(java.lang.Object):
            ALBUM: typing.ClassVar[str] = ...
            ALBUM_ART: typing.ClassVar[str] = ...
            ALBUM_ID: typing.ClassVar[str] = ...
            ALBUM_KEY: typing.ClassVar[str] = ...
            ARTIST: typing.ClassVar[str] = ...
            ARTIST_ID: typing.ClassVar[str] = ...
            ARTIST_KEY: typing.ClassVar[str] = ...
            FIRST_YEAR: typing.ClassVar[str] = ...
            LAST_YEAR: typing.ClassVar[str] = ...
            NUMBER_OF_SONGS: typing.ClassVar[str] = ...
            NUMBER_OF_SONGS_FOR_ARTIST: typing.ClassVar[str] = ...

class OpenableColumns(java.lang.Object):
    DISPLAY_NAME: typing.ClassVar[str] = ...
    SIZE: typing.ClassVar[str] = ...

class SearchRecentSuggestions(java.lang.Object):
    QUERIES_PROJECTION_1LINE: typing.ClassVar[java.chaquopy.JavaArray[java.lang.String]] = ...
    QUERIES_PROJECTION_2LINE: typing.ClassVar[java.chaquopy.JavaArray[java.lang.String]] = ...
    QUERIES_PROJECTION_DATE_INDEX: typing.ClassVar[int] = ...
    QUERIES_PROJECTION_DISPLAY1_INDEX: typing.ClassVar[int] = ...
    QUERIES_PROJECTION_DISPLAY2_INDEX: typing.ClassVar[int] = ...
    QUERIES_PROJECTION_QUERY_INDEX: typing.ClassVar[int] = ...
    def __init__(self, context: android.content.Context, authority: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearHistory(self) -> None: ...
    def saveRecentQuery(self, queryString: str | java.lang.String, line2: str | java.lang.String, /) -> None: ...
    def truncateHistory(self, cr: android.content.ContentResolver, maxEntries: int | java.jint | java.lang.Integer, /) -> None: ...

class Settings(java.lang.Object):
    ACTION_ACCESSIBILITY_SETTINGS: typing.ClassVar[str] = ...
    ACTION_ADD_ACCOUNT: typing.ClassVar[str] = ...
    ACTION_ADVANCED_MEMORY_PROTECTION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_AIRPLANE_MODE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_ALL_APPS_NOTIFICATION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APN_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APPLICATION_DETAILS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APPLICATION_DEVELOPMENT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APPLICATION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_LOCALE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_NOTIFICATION_BUBBLE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_NOTIFICATION_PROMOTION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_NOTIFICATION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_OPEN_BY_DEFAULT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_SEARCH_SETTINGS: typing.ClassVar[str] = ...
    ACTION_APP_USAGE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_AUTOMATIC_ZEN_RULE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_AUTO_ROTATE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_BATTERY_SAVER_SETTINGS: typing.ClassVar[str] = ...
    ACTION_BIOMETRIC_ENROLL: typing.ClassVar[str] = ...
    ACTION_BLUETOOTH_SETTINGS: typing.ClassVar[str] = ...
    ACTION_CAPTIONING_SETTINGS: typing.ClassVar[str] = ...
    ACTION_CAST_SETTINGS: typing.ClassVar[str] = ...
    ACTION_CHANNEL_NOTIFICATION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_CONDITION_PROVIDER_SETTINGS: typing.ClassVar[str] = ...
    ACTION_CREDENTIAL_PROVIDER: typing.ClassVar[str] = ...
    ACTION_DATA_ROAMING_SETTINGS: typing.ClassVar[str] = ...
    ACTION_DATA_USAGE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_DATE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_DEVICE_INFO_SETTINGS: typing.ClassVar[str] = ...
    ACTION_DISPLAY_SETTINGS: typing.ClassVar[str] = ...
    ACTION_DREAM_SETTINGS: typing.ClassVar[str] = ...
    ACTION_FINGERPRINT_ENROLL: typing.ClassVar[str] = ...
    ACTION_FIRST_DAY_OF_WEEK_SETTINGS: typing.ClassVar[str] = ...
    ACTION_HARD_KEYBOARD_SETTINGS: typing.ClassVar[str] = ...
    ACTION_HOME_SETTINGS: typing.ClassVar[str] = ...
    ACTION_IGNORE_BACKGROUND_DATA_RESTRICTIONS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_IGNORE_BATTERY_OPTIMIZATION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_INPUT_METHOD_SETTINGS: typing.ClassVar[str] = ...
    ACTION_INPUT_METHOD_SUBTYPE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_INTERNAL_STORAGE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_LOCALE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_LOCATION_SOURCE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MANAGE_ALL_APPLICATIONS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MANAGE_ALL_FILES_ACCESS_PERMISSION: typing.ClassVar[str] = ...
    ACTION_MANAGE_ALL_SIM_PROFILES_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MANAGE_APPLICATIONS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MANAGE_APP_ALL_FILES_ACCESS_PERMISSION: typing.ClassVar[str] = ...
    ACTION_MANAGE_APP_USE_FULL_SCREEN_INTENT: typing.ClassVar[str] = ...
    ACTION_MANAGE_DEFAULT_APPS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MANAGE_OVERLAY_PERMISSION: typing.ClassVar[str] = ...
    ACTION_MANAGE_SUPERVISOR_RESTRICTED_SETTING: typing.ClassVar[str] = ...
    ACTION_MANAGE_UNKNOWN_APP_SOURCES: typing.ClassVar[str] = ...
    ACTION_MANAGE_WRITE_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MEASUREMENT_SYSTEM_SETTINGS: typing.ClassVar[str] = ...
    ACTION_MEMORY_CARD_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NETWORK_OPERATOR_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NFCSHARING_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NFC_PAYMENT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NFC_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NIGHT_DISPLAY_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_ASSISTANT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_LISTENER_DETAIL_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_LISTENER_SETTINGS: typing.ClassVar[str] = ...
    ACTION_NOTIFICATION_POLICY_ACCESS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_PRINT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_PRIVACY_SETTINGS: typing.ClassVar[str] = ...
    ACTION_PROCESS_WIFI_EASY_CONNECT_URI: typing.ClassVar[str] = ...
    ACTION_QUICK_ACCESS_WALLET_SETTINGS: typing.ClassVar[str] = ...
    ACTION_QUICK_LAUNCH_SETTINGS: typing.ClassVar[str] = ...
    ACTION_REGIONAL_PREFERENCES_SETTINGS: typing.ClassVar[str] = ...
    ACTION_REGION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_REQUEST_IGNORE_BATTERY_OPTIMIZATIONS: typing.ClassVar[str] = ...
    ACTION_REQUEST_MANAGE_MEDIA: typing.ClassVar[str] = ...
    ACTION_REQUEST_MEDIA_ROUTING_CONTROL: typing.ClassVar[str] = ...
    ACTION_REQUEST_SCHEDULE_EXACT_ALARM: typing.ClassVar[str] = ...
    ACTION_REQUEST_SET_AUTOFILL_SERVICE: typing.ClassVar[str] = ...
    ACTION_SATELLITE_SETTING: typing.ClassVar[str] = ...
    ACTION_SEARCH_SETTINGS: typing.ClassVar[str] = ...
    ACTION_SECURITY_SETTINGS: typing.ClassVar[str] = ...
    ACTION_SETTINGS: typing.ClassVar[str] = ...
    ACTION_SETTINGS_EMBED_DEEP_LINK_ACTIVITY: typing.ClassVar[str] = ...
    ACTION_SHOW_REGULATORY_INFO: typing.ClassVar[str] = ...
    ACTION_SHOW_WORK_POLICY_INFO: typing.ClassVar[str] = ...
    ACTION_SOUND_SETTINGS: typing.ClassVar[str] = ...
    ACTION_STORAGE_VOLUME_ACCESS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_SYNC_SETTINGS: typing.ClassVar[str] = ...
    ACTION_TEMPERATURE_UNIT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_USAGE_ACCESS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_USER_DICTIONARY_SETTINGS: typing.ClassVar[str] = ...
    ACTION_VOICE_CONTROL_AIRPLANE_MODE: typing.ClassVar[str] = ...
    ACTION_VOICE_CONTROL_BATTERY_SAVER_MODE: typing.ClassVar[str] = ...
    ACTION_VOICE_CONTROL_DO_NOT_DISTURB_MODE: typing.ClassVar[str] = ...
    ACTION_VOICE_INPUT_SETTINGS: typing.ClassVar[str] = ...
    ACTION_VPN_SETTINGS: typing.ClassVar[str] = ...
    ACTION_VR_LISTENER_SETTINGS: typing.ClassVar[str] = ...
    ACTION_WEBVIEW_SETTINGS: typing.ClassVar[str] = ...
    ACTION_WIFI_ADD_NETWORKS: typing.ClassVar[str] = ...
    ACTION_WIFI_IP_SETTINGS: typing.ClassVar[str] = ...
    ACTION_WIFI_SETTINGS: typing.ClassVar[str] = ...
    ACTION_WIRELESS_SETTINGS: typing.ClassVar[str] = ...
    ACTION_ZEN_MODE_PRIORITY_SETTINGS: typing.ClassVar[str] = ...
    ADD_WIFI_RESULT_ADD_OR_UPDATE_FAILED: typing.ClassVar[int] = ...
    ADD_WIFI_RESULT_ALREADY_EXISTS: typing.ClassVar[int] = ...
    ADD_WIFI_RESULT_SUCCESS: typing.ClassVar[int] = ...
    AUTHORITY: typing.ClassVar[str] = ...
    EXTRA_ACCOUNT_TYPES: typing.ClassVar[str] = ...
    EXTRA_AIRPLANE_MODE_ENABLED: typing.ClassVar[str] = ...
    EXTRA_APP_PACKAGE: typing.ClassVar[str] = ...
    EXTRA_AUTHORITIES: typing.ClassVar[str] = ...
    EXTRA_AUTOMATIC_ZEN_RULE_ID: typing.ClassVar[str] = ...
    EXTRA_BATTERY_SAVER_MODE_ENABLED: typing.ClassVar[str] = ...
    EXTRA_BIOMETRIC_AUTHENTICATORS_ALLOWED: typing.ClassVar[str] = ...
    EXTRA_CHANNEL_FILTER_LIST: typing.ClassVar[str] = ...
    EXTRA_CHANNEL_ID: typing.ClassVar[str] = ...
    EXTRA_CONVERSATION_ID: typing.ClassVar[str] = ...
    EXTRA_DO_NOT_DISTURB_MODE_ENABLED: typing.ClassVar[str] = ...
    EXTRA_DO_NOT_DISTURB_MODE_MINUTES: typing.ClassVar[str] = ...
    EXTRA_EASY_CONNECT_ATTEMPTED_SSID: typing.ClassVar[str] = ...
    EXTRA_EASY_CONNECT_BAND_LIST: typing.ClassVar[str] = ...
    EXTRA_EASY_CONNECT_CHANNEL_LIST: typing.ClassVar[str] = ...
    EXTRA_EASY_CONNECT_ERROR_CODE: typing.ClassVar[str] = ...
    EXTRA_INPUT_METHOD_ID: typing.ClassVar[str] = ...
    EXTRA_NOTIFICATION_LISTENER_COMPONENT_NAME: typing.ClassVar[str] = ...
    EXTRA_SETTINGS_EMBEDDED_DEEP_LINK_HIGHLIGHT_MENU_KEY: typing.ClassVar[str] = ...
    EXTRA_SETTINGS_EMBEDDED_DEEP_LINK_INTENT_URI: typing.ClassVar[str] = ...
    EXTRA_SUB_ID: typing.ClassVar[str] = ...
    EXTRA_SUPERVISOR_RESTRICTED_SETTING_KEY: typing.ClassVar[str] = ...
    EXTRA_WIFI_NETWORK_LIST: typing.ClassVar[str] = ...
    EXTRA_WIFI_NETWORK_RESULT_LIST: typing.ClassVar[str] = ...
    INTENT_CATEGORY_USAGE_ACCESS_CONFIG: typing.ClassVar[str] = ...
    METADATA_USAGE_ACCESS_REASON: typing.ClassVar[str] = ...
    SUPERVISOR_VERIFICATION_SETTING_BIOMETRICS: typing.ClassVar[int] = ...
    SUPERVISOR_VERIFICATION_SETTING_UNKNOWN: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def canDrawOverlays(context: android.content.Context, /) -> bool: ...

    class System(Settings.NameValueTable):
        ACCELEROMETER_ROTATION: typing.ClassVar[str] = ...
        ADB_ENABLED: typing.ClassVar[str] = ...
        AIRPLANE_MODE_ON: typing.ClassVar[str] = ...
        AIRPLANE_MODE_RADIOS: typing.ClassVar[str] = ...
        ALARM_ALERT: typing.ClassVar[str] = ...
        ALWAYS_FINISH_ACTIVITIES: typing.ClassVar[str] = ...
        ANDROID_ID: typing.ClassVar[str] = ...
        ANIMATOR_DURATION_SCALE: typing.ClassVar[str] = ...
        AUTO_TIME: typing.ClassVar[str] = ...
        AUTO_TIME_ZONE: typing.ClassVar[str] = ...
        BLUETOOTH_DISCOVERABILITY: typing.ClassVar[str] = ...
        BLUETOOTH_DISCOVERABILITY_TIMEOUT: typing.ClassVar[str] = ...
        BLUETOOTH_ON: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATA_ROAMING: typing.ClassVar[str] = ...
        DATE_FORMAT: typing.ClassVar[str] = ...
        DEBUG_APP: typing.ClassVar[str] = ...
        DEFAULT_ALARM_ALERT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_NOTIFICATION_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_RINGTONE_URI: typing.ClassVar[android.net.Uri] = ...
        DEVICE_PROVISIONED: typing.ClassVar[str] = ...
        DIM_SCREEN: typing.ClassVar[str] = ...
        DTMF_TONE_TYPE_WHEN_DIALING: typing.ClassVar[str] = ...
        DTMF_TONE_WHEN_DIALING: typing.ClassVar[str] = ...
        END_BUTTON_BEHAVIOR: typing.ClassVar[str] = ...
        FONT_SCALE: typing.ClassVar[str] = ...
        HAPTIC_FEEDBACK_ENABLED: typing.ClassVar[str] = ...
        HTTP_PROXY: typing.ClassVar[str] = ...
        INSTALL_NON_MARKET_APPS: typing.ClassVar[str] = ...
        LOCATION_PROVIDERS_ALLOWED: typing.ClassVar[str] = ...
        LOCK_PATTERN_ENABLED: typing.ClassVar[str] = ...
        LOCK_PATTERN_TACTILE_FEEDBACK_ENABLED: typing.ClassVar[str] = ...
        LOCK_PATTERN_VISIBLE: typing.ClassVar[str] = ...
        LOGGING_ID: typing.ClassVar[str] = ...
        MODE_RINGER: typing.ClassVar[str] = ...
        MODE_RINGER_STREAMS_AFFECTED: typing.ClassVar[str] = ...
        MUTE_STREAMS_AFFECTED: typing.ClassVar[str] = ...
        NETWORK_PREFERENCE: typing.ClassVar[str] = ...
        NEXT_ALARM_FORMATTED: typing.ClassVar[str] = ...
        NOTIFICATION_SOUND: typing.ClassVar[str] = ...
        PARENTAL_CONTROL_ENABLED: typing.ClassVar[str] = ...
        PARENTAL_CONTROL_LAST_UPDATE: typing.ClassVar[str] = ...
        PARENTAL_CONTROL_REDIRECT_URL: typing.ClassVar[str] = ...
        RADIO_BLUETOOTH: typing.ClassVar[str] = ...
        RADIO_CELL: typing.ClassVar[str] = ...
        RADIO_NFC: typing.ClassVar[str] = ...
        RADIO_WIFI: typing.ClassVar[str] = ...
        RINGTONE: typing.ClassVar[str] = ...
        SCREEN_BRIGHTNESS: typing.ClassVar[str] = ...
        SCREEN_BRIGHTNESS_MODE: typing.ClassVar[str] = ...
        SCREEN_BRIGHTNESS_MODE_AUTOMATIC: typing.ClassVar[int] = ...
        SCREEN_BRIGHTNESS_MODE_MANUAL: typing.ClassVar[int] = ...
        SCREEN_OFF_TIMEOUT: typing.ClassVar[str] = ...
        SETTINGS_CLASSNAME: typing.ClassVar[str] = ...
        SETUP_WIZARD_HAS_RUN: typing.ClassVar[str] = ...
        SHOW_GTALK_SERVICE_STATUS: typing.ClassVar[str] = ...
        SHOW_PROCESSES: typing.ClassVar[str] = ...
        SHOW_WEB_SUGGESTIONS: typing.ClassVar[str] = ...
        SOUND_EFFECTS_ENABLED: typing.ClassVar[str] = ...
        STAY_ON_WHILE_PLUGGED_IN: typing.ClassVar[str] = ...
        TEXT_AUTO_CAPS: typing.ClassVar[str] = ...
        TEXT_AUTO_PUNCTUATE: typing.ClassVar[str] = ...
        TEXT_AUTO_REPLACE: typing.ClassVar[str] = ...
        TEXT_SHOW_PASSWORD: typing.ClassVar[str] = ...
        TIME_12_24: typing.ClassVar[str] = ...
        TRANSITION_ANIMATION_SCALE: typing.ClassVar[str] = ...
        USB_MASS_STORAGE_ENABLED: typing.ClassVar[str] = ...
        USER_ROTATION: typing.ClassVar[str] = ...
        USE_GOOGLE_MAIL: typing.ClassVar[str] = ...
        VIBRATE_ON: typing.ClassVar[str] = ...
        VIBRATE_WHEN_RINGING: typing.ClassVar[str] = ...
        WAIT_FOR_DEBUGGER: typing.ClassVar[str] = ...
        WALLPAPER_ACTIVITY: typing.ClassVar[str] = ...
        WIFI_MAX_DHCP_RETRY_COUNT: typing.ClassVar[str] = ...
        WIFI_MOBILE_DATA_TRANSITION_WAKELOCK_TIMEOUT_MS: typing.ClassVar[str] = ...
        WIFI_NETWORKS_AVAILABLE_NOTIFICATION_ON: typing.ClassVar[str] = ...
        WIFI_NETWORKS_AVAILABLE_REPEAT_DELAY: typing.ClassVar[str] = ...
        WIFI_NUM_OPEN_NETWORKS_KEPT: typing.ClassVar[str] = ...
        WIFI_ON: typing.ClassVar[str] = ...
        WIFI_SLEEP_POLICY: typing.ClassVar[str] = ...
        WIFI_SLEEP_POLICY_DEFAULT: typing.ClassVar[int] = ...
        WIFI_SLEEP_POLICY_NEVER: typing.ClassVar[int] = ...
        WIFI_SLEEP_POLICY_NEVER_WHILE_PLUGGED: typing.ClassVar[int] = ...
        WIFI_STATIC_DNS1: typing.ClassVar[str] = ...
        WIFI_STATIC_DNS2: typing.ClassVar[str] = ...
        WIFI_STATIC_GATEWAY: typing.ClassVar[str] = ...
        WIFI_STATIC_IP: typing.ClassVar[str] = ...
        WIFI_STATIC_NETMASK: typing.ClassVar[str] = ...
        WIFI_USE_STATIC_IP: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_ACCEPTABLE_PACKET_LOSS_PERCENTAGE: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_AP_COUNT: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_BACKGROUND_CHECK_DELAY_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_BACKGROUND_CHECK_ENABLED: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_BACKGROUND_CHECK_TIMEOUT_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_INITIAL_IGNORED_PING_COUNT: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_MAX_AP_CHECKS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_ON: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_PING_COUNT: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_PING_DELAY_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_PING_TIMEOUT_MS: typing.ClassVar[str] = ...
        WINDOW_ANIMATION_SCALE: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @staticmethod
        def canWrite(context: android.content.Context, /) -> bool: ...
        @staticmethod
        def getConfiguration(cr: android.content.ContentResolver, outConfig: android.content.res.Configuration, /) -> None: ...
        @typing.overload
        @staticmethod
        def getFloat(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> float: ...
        @typing.overload
        @staticmethod
        def getFloat(cr: android.content.ContentResolver, name: str | java.lang.String, def_: float | java.jfloat | java.lang.Float, /) -> float: ...
        @typing.overload
        @staticmethod
        def getInt(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getInt(cr: android.content.ContentResolver, name: str | java.lang.String, def_: int | java.jint | java.lang.Integer, /) -> int: ...
        @typing.overload
        @staticmethod
        def getLong(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getLong(cr: android.content.ContentResolver, name: str | java.lang.String, def_: int | java.jlong | java.lang.Long, /) -> int: ...
        @staticmethod
        def getShowGTalkServiceStatus(cr: android.content.ContentResolver, /) -> bool: ...
        @staticmethod
        def getString(resolver: android.content.ContentResolver, name: str | java.lang.String, /) -> str: ...
        @staticmethod
        def getUriFor(name: str | java.lang.String, /) -> android.net.Uri: ...
        @staticmethod
        def putConfiguration(cr: android.content.ContentResolver, config: android.content.res.Configuration, /) -> bool: ...
        @staticmethod
        def putFloat(cr: android.content.ContentResolver, name: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> bool: ...
        @staticmethod
        def putInt(cr: android.content.ContentResolver, name: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> bool: ...
        @staticmethod
        def putLong(cr: android.content.ContentResolver, name: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> bool: ...
        @staticmethod
        def putString(resolver: android.content.ContentResolver, name: str | java.lang.String, value: str | java.lang.String, /) -> bool: ...
        @staticmethod
        def setShowGTalkServiceStatus(cr: android.content.ContentResolver, flag: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class SettingNotFoundException(android.util.AndroidException):
        def __init__(self, msg: str | java.lang.String, /) -> None: ...

    class Secure(Settings.NameValueTable):
        ACCESSIBILITY_DISPLAY_INVERSION_ENABLED: typing.ClassVar[str] = ...
        ACCESSIBILITY_ENABLED: typing.ClassVar[str] = ...
        ACCESSIBILITY_SPEAK_PASSWORD: typing.ClassVar[str] = ...
        ADB_ENABLED: typing.ClassVar[str] = ...
        ALLOWED_GEOLOCATION_ORIGINS: typing.ClassVar[str] = ...
        ALLOW_MOCK_LOCATION: typing.ClassVar[str] = ...
        ANDROID_ID: typing.ClassVar[str] = ...
        BACKGROUND_DATA: typing.ClassVar[str] = ...
        BLUETOOTH_ON: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATA_ROAMING: typing.ClassVar[str] = ...
        DEFAULT_INPUT_METHOD: typing.ClassVar[str] = ...
        DEVELOPMENT_SETTINGS_ENABLED: typing.ClassVar[str] = ...
        DEVICE_PROVISIONED: typing.ClassVar[str] = ...
        ENABLED_ACCESSIBILITY_SERVICES: typing.ClassVar[str] = ...
        ENABLED_INPUT_METHODS: typing.ClassVar[str] = ...
        HTTP_PROXY: typing.ClassVar[str] = ...
        INPUT_METHOD_SELECTOR_VISIBILITY: typing.ClassVar[str] = ...
        INSTALL_NON_MARKET_APPS: typing.ClassVar[str] = ...
        LOCATION_MODE: typing.ClassVar[str] = ...
        LOCATION_MODE_BATTERY_SAVING: typing.ClassVar[int] = ...
        LOCATION_MODE_HIGH_ACCURACY: typing.ClassVar[int] = ...
        LOCATION_MODE_OFF: typing.ClassVar[int] = ...
        LOCATION_MODE_SENSORS_ONLY: typing.ClassVar[int] = ...
        LOCATION_PROVIDERS_ALLOWED: typing.ClassVar[str] = ...
        LOCK_PATTERN_ENABLED: typing.ClassVar[str] = ...
        LOCK_PATTERN_TACTILE_FEEDBACK_ENABLED: typing.ClassVar[str] = ...
        LOCK_PATTERN_VISIBLE: typing.ClassVar[str] = ...
        LOGGING_ID: typing.ClassVar[str] = ...
        NETWORK_PREFERENCE: typing.ClassVar[str] = ...
        PARENTAL_CONTROL_ENABLED: typing.ClassVar[str] = ...
        PARENTAL_CONTROL_LAST_UPDATE: typing.ClassVar[str] = ...
        PARENTAL_CONTROL_REDIRECT_URL: typing.ClassVar[str] = ...
        RTT_CALLING_MODE: typing.ClassVar[str] = ...
        SECURE_FRP_MODE: typing.ClassVar[str] = ...
        SELECTED_INPUT_METHOD_SUBTYPE: typing.ClassVar[str] = ...
        SETTINGS_CLASSNAME: typing.ClassVar[str] = ...
        SKIP_FIRST_USE_HINTS: typing.ClassVar[str] = ...
        TOUCH_EXPLORATION_ENABLED: typing.ClassVar[str] = ...
        TTS_DEFAULT_COUNTRY: typing.ClassVar[str] = ...
        TTS_DEFAULT_LANG: typing.ClassVar[str] = ...
        TTS_DEFAULT_PITCH: typing.ClassVar[str] = ...
        TTS_DEFAULT_RATE: typing.ClassVar[str] = ...
        TTS_DEFAULT_SYNTH: typing.ClassVar[str] = ...
        TTS_DEFAULT_VARIANT: typing.ClassVar[str] = ...
        TTS_ENABLED_PLUGINS: typing.ClassVar[str] = ...
        TTS_USE_DEFAULTS: typing.ClassVar[str] = ...
        USB_MASS_STORAGE_ENABLED: typing.ClassVar[str] = ...
        USE_GOOGLE_MAIL: typing.ClassVar[str] = ...
        WIFI_MAX_DHCP_RETRY_COUNT: typing.ClassVar[str] = ...
        WIFI_MOBILE_DATA_TRANSITION_WAKELOCK_TIMEOUT_MS: typing.ClassVar[str] = ...
        WIFI_NETWORKS_AVAILABLE_NOTIFICATION_ON: typing.ClassVar[str] = ...
        WIFI_NETWORKS_AVAILABLE_REPEAT_DELAY: typing.ClassVar[str] = ...
        WIFI_NUM_OPEN_NETWORKS_KEPT: typing.ClassVar[str] = ...
        WIFI_ON: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_ACCEPTABLE_PACKET_LOSS_PERCENTAGE: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_AP_COUNT: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_BACKGROUND_CHECK_DELAY_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_BACKGROUND_CHECK_ENABLED: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_BACKGROUND_CHECK_TIMEOUT_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_INITIAL_IGNORED_PING_COUNT: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_MAX_AP_CHECKS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_ON: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_PING_COUNT: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_PING_DELAY_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_PING_TIMEOUT_MS: typing.ClassVar[str] = ...
        WIFI_WATCHDOG_WATCH_LIST: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @typing.overload
        @staticmethod
        def getFloat(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> float: ...
        @typing.overload
        @staticmethod
        def getFloat(cr: android.content.ContentResolver, name: str | java.lang.String, def_: float | java.jfloat | java.lang.Float, /) -> float: ...
        @typing.overload
        @staticmethod
        def getInt(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getInt(cr: android.content.ContentResolver, name: str | java.lang.String, def_: int | java.jint | java.lang.Integer, /) -> int: ...
        @typing.overload
        @staticmethod
        def getLong(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getLong(cr: android.content.ContentResolver, name: str | java.lang.String, def_: int | java.jlong | java.lang.Long, /) -> int: ...
        @staticmethod
        def getString(resolver: android.content.ContentResolver, name: str | java.lang.String, /) -> str: ...
        @staticmethod
        def getUriFor(name: str | java.lang.String, /) -> android.net.Uri: ...
        @staticmethod
        def isLocationProviderEnabled(cr: android.content.ContentResolver, provider: str | java.lang.String, /) -> bool: ...
        @staticmethod
        def putFloat(cr: android.content.ContentResolver, name: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> bool: ...
        @staticmethod
        def putInt(cr: android.content.ContentResolver, name: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> bool: ...
        @staticmethod
        def putLong(cr: android.content.ContentResolver, name: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> bool: ...
        @staticmethod
        def putString(resolver: android.content.ContentResolver, name: str | java.lang.String, value: str | java.lang.String, /) -> bool: ...
        @staticmethod
        def setLocationProviderEnabled(cr: android.content.ContentResolver, provider: str | java.lang.String, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class Panel(java.lang.Object):
        ACTION_INTERNET_CONNECTIVITY: typing.ClassVar[str] = ...
        ACTION_NFC: typing.ClassVar[str] = ...
        ACTION_VOLUME: typing.ClassVar[str] = ...
        ACTION_WIFI: typing.ClassVar[str] = ...

    class NameValueTable(BaseColumns):
        NAME: typing.ClassVar[str] = ...
        VALUE: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @staticmethod
        def getUriFor(uri: android.net.Uri, name: str | java.lang.String, /) -> android.net.Uri: ...
        @staticmethod
        def putString(resolver: android.content.ContentResolver, uri: android.net.Uri, name: str | java.lang.String, value: str | java.lang.String, /) -> bool: ...

    class Global(Settings.NameValueTable):
        ADB_ENABLED: typing.ClassVar[str] = ...
        AIRPLANE_MODE_ON: typing.ClassVar[str] = ...
        AIRPLANE_MODE_RADIOS: typing.ClassVar[str] = ...
        ALWAYS_FINISH_ACTIVITIES: typing.ClassVar[str] = ...
        ANIMATOR_DURATION_SCALE: typing.ClassVar[str] = ...
        APPLY_RAMPING_RINGER: typing.ClassVar[str] = ...
        AUTO_TIME: typing.ClassVar[str] = ...
        AUTO_TIME_ZONE: typing.ClassVar[str] = ...
        BLUETOOTH_ON: typing.ClassVar[str] = ...
        BOOT_COUNT: typing.ClassVar[str] = ...
        CONTACT_METADATA_SYNC_ENABLED: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATA_ROAMING: typing.ClassVar[str] = ...
        DEBUG_APP: typing.ClassVar[str] = ...
        DEVELOPMENT_SETTINGS_ENABLED: typing.ClassVar[str] = ...
        DEVICE_NAME: typing.ClassVar[str] = ...
        DEVICE_PROVISIONED: typing.ClassVar[str] = ...
        HTTP_PROXY: typing.ClassVar[str] = ...
        INSTALL_NON_MARKET_APPS: typing.ClassVar[str] = ...
        MODE_RINGER: typing.ClassVar[str] = ...
        NETWORK_PREFERENCE: typing.ClassVar[str] = ...
        RADIO_BLUETOOTH: typing.ClassVar[str] = ...
        RADIO_CELL: typing.ClassVar[str] = ...
        RADIO_NFC: typing.ClassVar[str] = ...
        RADIO_WIFI: typing.ClassVar[str] = ...
        SECURE_FRP_MODE: typing.ClassVar[str] = ...
        SHOW_PROCESSES: typing.ClassVar[str] = ...
        STAY_ON_WHILE_PLUGGED_IN: typing.ClassVar[str] = ...
        TRANSITION_ANIMATION_SCALE: typing.ClassVar[str] = ...
        USB_MASS_STORAGE_ENABLED: typing.ClassVar[str] = ...
        USE_GOOGLE_MAIL: typing.ClassVar[str] = ...
        WAIT_FOR_DEBUGGER: typing.ClassVar[str] = ...
        WIFI_DEVICE_OWNER_CONFIGS_LOCKDOWN: typing.ClassVar[str] = ...
        WIFI_MAX_DHCP_RETRY_COUNT: typing.ClassVar[str] = ...
        WIFI_MOBILE_DATA_TRANSITION_WAKELOCK_TIMEOUT_MS: typing.ClassVar[str] = ...
        WIFI_NETWORKS_AVAILABLE_NOTIFICATION_ON: typing.ClassVar[str] = ...
        WIFI_NETWORKS_AVAILABLE_REPEAT_DELAY: typing.ClassVar[str] = ...
        WIFI_NUM_OPEN_NETWORKS_KEPT: typing.ClassVar[str] = ...
        WIFI_ON: typing.ClassVar[str] = ...
        WIFI_SLEEP_POLICY: typing.ClassVar[str] = ...
        WIFI_SLEEP_POLICY_DEFAULT: typing.ClassVar[int] = ...
        WIFI_SLEEP_POLICY_NEVER: typing.ClassVar[int] = ...
        WIFI_SLEEP_POLICY_NEVER_WHILE_PLUGGED: typing.ClassVar[int] = ...
        WIFI_WATCHDOG_ON: typing.ClassVar[str] = ...
        WINDOW_ANIMATION_SCALE: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @typing.overload
        @staticmethod
        def getFloat(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> float: ...
        @typing.overload
        @staticmethod
        def getFloat(cr: android.content.ContentResolver, name: str | java.lang.String, def_: float | java.jfloat | java.lang.Float, /) -> float: ...
        @typing.overload
        @staticmethod
        def getInt(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getInt(cr: android.content.ContentResolver, name: str | java.lang.String, def_: int | java.jint | java.lang.Integer, /) -> int: ...
        @typing.overload
        @staticmethod
        def getLong(cr: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getLong(cr: android.content.ContentResolver, name: str | java.lang.String, def_: int | java.jlong | java.lang.Long, /) -> int: ...
        @staticmethod
        def getString(resolver: android.content.ContentResolver, name: str | java.lang.String, /) -> str: ...
        @staticmethod
        def getUriFor(name: str | java.lang.String, /) -> android.net.Uri: ...
        @staticmethod
        def putFloat(cr: android.content.ContentResolver, name: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> bool: ...
        @staticmethod
        def putInt(cr: android.content.ContentResolver, name: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> bool: ...
        @staticmethod
        def putLong(cr: android.content.ContentResolver, name: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> bool: ...
        @staticmethod
        def putString(resolver: android.content.ContentResolver, name: str | java.lang.String, value: str | java.lang.String, /) -> bool: ...

class SettingsSlicesContract(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    BASE_URI: typing.ClassVar[android.net.Uri] = ...
    KEY_AIRPLANE_MODE: typing.ClassVar[str] = ...
    KEY_BATTERY_SAVER: typing.ClassVar[str] = ...
    KEY_BLUETOOTH: typing.ClassVar[str] = ...
    KEY_LOCATION: typing.ClassVar[str] = ...
    KEY_WIFI: typing.ClassVar[str] = ...
    PATH_SETTING_ACTION: typing.ClassVar[str] = ...
    PATH_SETTING_INTENT: typing.ClassVar[str] = ...

class SimPhonebookContract(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    AUTHORITY_URI: typing.ClassVar[android.net.Uri] = ...

    class SimRecords(java.lang.Object):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        ELEMENTARY_FILE_TYPE: typing.ClassVar[str] = ...
        ERROR_NAME_UNSUPPORTED: typing.ClassVar[int] = ...
        NAME: typing.ClassVar[str] = ...
        PHONE_NUMBER: typing.ClassVar[str] = ...
        RECORD_NUMBER: typing.ClassVar[str] = ...
        SUBSCRIPTION_ID: typing.ClassVar[str] = ...
        @staticmethod
        def getContentUri(subscriptionId: int | java.jint | java.lang.Integer, efType: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...
        @staticmethod
        def getEncodedNameLength(resolver: android.content.ContentResolver, name: str | java.lang.String, /) -> int: ...
        @staticmethod
        def getItemUri(subscriptionId: int | java.jint | java.lang.Integer, efType: int | java.jint | java.lang.Integer, recordNumber: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...

    class ElementaryFiles(java.lang.Object):
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        EF_ADN: typing.ClassVar[int] = ...
        EF_FDN: typing.ClassVar[int] = ...
        EF_SDN: typing.ClassVar[int] = ...
        EF_TYPE: typing.ClassVar[str] = ...
        EF_UNKNOWN: typing.ClassVar[int] = ...
        MAX_RECORDS: typing.ClassVar[str] = ...
        NAME_MAX_LENGTH: typing.ClassVar[str] = ...
        PHONE_NUMBER_MAX_LENGTH: typing.ClassVar[str] = ...
        RECORD_COUNT: typing.ClassVar[str] = ...
        SLOT_INDEX: typing.ClassVar[str] = ...
        SUBSCRIPTION_ID: typing.ClassVar[str] = ...
        @staticmethod
        def getItemUri(subscriptionId: int | java.jint | java.lang.Integer, efType: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...

class SyncStateContract(java.lang.Object):
    def __init__(self) -> None: ...

    class Helpers(java.lang.Object):
        def __init__(self) -> None: ...
        @staticmethod
        def get(provider: android.content.ContentProviderClient, uri: android.net.Uri, account: android.accounts.Account, /) -> java.chaquopy.JavaArrayJByte: ...
        @staticmethod
        def getWithUri(provider: android.content.ContentProviderClient, uri: android.net.Uri, account: android.accounts.Account, /) -> android.util.Pair[android.net.Uri, java.chaquopy.JavaArrayJByte]: ...
        @staticmethod
        def insert(provider: android.content.ContentProviderClient, uri: android.net.Uri, account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> android.net.Uri: ...
        @staticmethod
        def newSetOperation(uri: android.net.Uri, account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> android.content.ContentProviderOperation: ...
        @staticmethod
        def newUpdateOperation(uri: android.net.Uri, data: java.chaquopy.JavaArrayJByte, /) -> android.content.ContentProviderOperation: ...
        @staticmethod
        def set(provider: android.content.ContentProviderClient, uri: android.net.Uri, account: android.accounts.Account, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        @staticmethod
        def update(provider: android.content.ContentProviderClient, uri: android.net.Uri, data: java.chaquopy.JavaArrayJByte, /) -> None: ...

    class Constants(SyncStateContract.Columns):
        CONTENT_DIRECTORY: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...

    class Columns(BaseColumns):
        ACCOUNT_NAME: typing.ClassVar[str] = ...
        ACCOUNT_TYPE: typing.ClassVar[str] = ...
        DATA: typing.ClassVar[str] = ...

class Telephony(java.lang.Object):

    class ThreadsColumns(BaseColumns):
        ARCHIVED: typing.ClassVar[str] = ...
        DATE: typing.ClassVar[str] = ...
        ERROR: typing.ClassVar[str] = ...
        HAS_ATTACHMENT: typing.ClassVar[str] = ...
        MESSAGE_COUNT: typing.ClassVar[str] = ...
        READ: typing.ClassVar[str] = ...
        RECIPIENT_IDS: typing.ClassVar[str] = ...
        SNIPPET: typing.ClassVar[str] = ...
        SNIPPET_CHARSET: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...

    class Threads(Telephony.ThreadsColumns):
        BROADCAST_THREAD: typing.ClassVar[int] = ...
        COMMON_THREAD: typing.ClassVar[int] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        OBSOLETE_THREADS_URI: typing.ClassVar[android.net.Uri] = ...
        @typing.overload
        @staticmethod
        def getOrCreateThreadId(context: android.content.Context, recipient: str | java.lang.String, /) -> int: ...
        @typing.overload
        @staticmethod
        def getOrCreateThreadId(context: android.content.Context, recipients: java.util.Set[java.lang.String], /) -> int: ...

    class TextBasedSmsColumns(java.lang.Object):
        ADDRESS: typing.ClassVar[str] = ...
        BODY: typing.ClassVar[str] = ...
        CREATOR: typing.ClassVar[str] = ...
        DATE: typing.ClassVar[str] = ...
        DATE_SENT: typing.ClassVar[str] = ...
        ERROR_CODE: typing.ClassVar[str] = ...
        LOCKED: typing.ClassVar[str] = ...
        MESSAGE_TYPE_ALL: typing.ClassVar[int] = ...
        MESSAGE_TYPE_DRAFT: typing.ClassVar[int] = ...
        MESSAGE_TYPE_FAILED: typing.ClassVar[int] = ...
        MESSAGE_TYPE_INBOX: typing.ClassVar[int] = ...
        MESSAGE_TYPE_OUTBOX: typing.ClassVar[int] = ...
        MESSAGE_TYPE_QUEUED: typing.ClassVar[int] = ...
        MESSAGE_TYPE_SENT: typing.ClassVar[int] = ...
        PERSON: typing.ClassVar[str] = ...
        PROTOCOL: typing.ClassVar[str] = ...
        READ: typing.ClassVar[str] = ...
        REPLY_PATH_PRESENT: typing.ClassVar[str] = ...
        SEEN: typing.ClassVar[str] = ...
        SERVICE_CENTER: typing.ClassVar[str] = ...
        STATUS: typing.ClassVar[str] = ...
        STATUS_COMPLETE: typing.ClassVar[int] = ...
        STATUS_FAILED: typing.ClassVar[int] = ...
        STATUS_NONE: typing.ClassVar[int] = ...
        STATUS_PENDING: typing.ClassVar[int] = ...
        SUBJECT: typing.ClassVar[str] = ...
        SUBSCRIPTION_ID: typing.ClassVar[str] = ...
        THREAD_ID: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...

    class Sms(BaseColumns, Telephony.TextBasedSmsColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        @staticmethod
        def getDefaultSmsPackage(context: android.content.Context, /) -> str: ...

        class Sent(BaseColumns, Telephony.TextBasedSmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Outbox(BaseColumns, Telephony.TextBasedSmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Intents(java.lang.Object):
            ACTION_CHANGE_DEFAULT: typing.ClassVar[str] = ...
            ACTION_DEFAULT_SMS_PACKAGE_CHANGED: typing.ClassVar[str] = ...
            ACTION_EXTERNAL_PROVIDER_CHANGE: typing.ClassVar[str] = ...
            DATA_SMS_RECEIVED_ACTION: typing.ClassVar[str] = ...
            EXTRA_IS_DEFAULT_SMS_APP: typing.ClassVar[str] = ...
            EXTRA_PACKAGE_NAME: typing.ClassVar[str] = ...
            RESULT_SMS_DATABASE_ERROR: typing.ClassVar[int] = ...
            RESULT_SMS_DISPATCH_FAILURE: typing.ClassVar[int] = ...
            RESULT_SMS_DUPLICATED: typing.ClassVar[int] = ...
            RESULT_SMS_GENERIC_ERROR: typing.ClassVar[int] = ...
            RESULT_SMS_HANDLED: typing.ClassVar[int] = ...
            RESULT_SMS_INVALID_URI: typing.ClassVar[int] = ...
            RESULT_SMS_NULL_MESSAGE: typing.ClassVar[int] = ...
            RESULT_SMS_NULL_PDU: typing.ClassVar[int] = ...
            RESULT_SMS_OUT_OF_MEMORY: typing.ClassVar[int] = ...
            RESULT_SMS_RECEIVED_WHILE_ENCRYPTED: typing.ClassVar[int] = ...
            RESULT_SMS_UNSUPPORTED: typing.ClassVar[int] = ...
            SECRET_CODE_ACTION: typing.ClassVar[str] = ...
            SIM_FULL_ACTION: typing.ClassVar[str] = ...
            SMS_CB_RECEIVED_ACTION: typing.ClassVar[str] = ...
            SMS_DELIVER_ACTION: typing.ClassVar[str] = ...
            SMS_RECEIVED_ACTION: typing.ClassVar[str] = ...
            SMS_REJECTED_ACTION: typing.ClassVar[str] = ...
            SMS_SERVICE_CATEGORY_PROGRAM_DATA_RECEIVED_ACTION: typing.ClassVar[str] = ...
            WAP_PUSH_DELIVER_ACTION: typing.ClassVar[str] = ...
            WAP_PUSH_RECEIVED_ACTION: typing.ClassVar[str] = ...
            @staticmethod
            def getMessagesFromIntent(intent: android.content.Intent, /) -> java.chaquopy.JavaArray[android.telephony.SmsMessage]: ...

        class Inbox(BaseColumns, Telephony.TextBasedSmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Draft(BaseColumns, Telephony.TextBasedSmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Conversations(BaseColumns, Telephony.TextBasedSmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
            MESSAGE_COUNT: typing.ClassVar[str] = ...
            SNIPPET: typing.ClassVar[str] = ...

    class ServiceStateTable(java.lang.Object):
        AUTHORITY: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATA_NETWORK_TYPE: typing.ClassVar[str] = ...
        DATA_REG_STATE: typing.ClassVar[str] = ...
        DUPLEX_MODE: typing.ClassVar[str] = ...
        IS_MANUAL_NETWORK_SELECTION: typing.ClassVar[str] = ...
        VOICE_OPERATOR_NUMERIC: typing.ClassVar[str] = ...
        VOICE_REG_STATE: typing.ClassVar[str] = ...
        @staticmethod
        def getUriForSubscriptionId(subscriptionId: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...
        @staticmethod
        def getUriForSubscriptionIdAndField(subscriptionId: int | java.jint | java.lang.Integer, field: str | java.lang.String, /) -> android.net.Uri: ...

    class MmsSms(BaseColumns):
        CONTENT_CONVERSATIONS_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_DRAFT_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_FILTER_BYPHONE_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_LOCKED_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_UNDELIVERED_URI: typing.ClassVar[android.net.Uri] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        ERR_TYPE_GENERIC: typing.ClassVar[int] = ...
        ERR_TYPE_GENERIC_PERMANENT: typing.ClassVar[int] = ...
        ERR_TYPE_MMS_PROTO_PERMANENT: typing.ClassVar[int] = ...
        ERR_TYPE_MMS_PROTO_TRANSIENT: typing.ClassVar[int] = ...
        ERR_TYPE_SMS_PROTO_PERMANENT: typing.ClassVar[int] = ...
        ERR_TYPE_SMS_PROTO_TRANSIENT: typing.ClassVar[int] = ...
        ERR_TYPE_TRANSPORT_FAILURE: typing.ClassVar[int] = ...
        MMS_PROTO: typing.ClassVar[int] = ...
        NO_ERROR: typing.ClassVar[int] = ...
        SEARCH_URI: typing.ClassVar[android.net.Uri] = ...
        SMS_PROTO: typing.ClassVar[int] = ...
        TYPE_DISCRIMINATOR_COLUMN: typing.ClassVar[str] = ...

        class PendingMessages(BaseColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DUE_TIME: typing.ClassVar[str] = ...
            ERROR_CODE: typing.ClassVar[str] = ...
            ERROR_TYPE: typing.ClassVar[str] = ...
            LAST_TRY: typing.ClassVar[str] = ...
            MSG_ID: typing.ClassVar[str] = ...
            MSG_TYPE: typing.ClassVar[str] = ...
            PROTO_TYPE: typing.ClassVar[str] = ...
            RETRY_INDEX: typing.ClassVar[str] = ...
            SUBSCRIPTION_ID: typing.ClassVar[str] = ...

    class Mms(Telephony.BaseMmsColumns):
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        REPORT_REQUEST_URI: typing.ClassVar[android.net.Uri] = ...
        REPORT_STATUS_URI: typing.ClassVar[android.net.Uri] = ...

        class Sent(Telephony.BaseMmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Rate(java.lang.Object):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            SENT_TIME: typing.ClassVar[str] = ...

        class Part(BaseColumns):
            CHARSET: typing.ClassVar[str] = ...
            CONTENT_DISPOSITION: typing.ClassVar[str] = ...
            CONTENT_ID: typing.ClassVar[str] = ...
            CONTENT_LOCATION: typing.ClassVar[str] = ...
            CONTENT_TYPE: typing.ClassVar[str] = ...
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            CT_START: typing.ClassVar[str] = ...
            CT_TYPE: typing.ClassVar[str] = ...
            FILENAME: typing.ClassVar[str] = ...
            MSG_ID: typing.ClassVar[str] = ...
            NAME: typing.ClassVar[str] = ...
            SEQ: typing.ClassVar[str] = ...
            TEXT: typing.ClassVar[str] = ...
            _DATA: typing.ClassVar[str] = ...
            @staticmethod
            def getPartUriForMessage(messageId: str | java.lang.String, /) -> android.net.Uri: ...

        class Outbox(Telephony.BaseMmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Intents(java.lang.Object):
            CONTENT_CHANGED_ACTION: typing.ClassVar[str] = ...
            DELETED_CONTENTS: typing.ClassVar[str] = ...

        class Inbox(Telephony.BaseMmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Draft(Telephony.BaseMmsColumns):
            CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
            DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...

        class Addr(BaseColumns):
            ADDRESS: typing.ClassVar[str] = ...
            CHARSET: typing.ClassVar[str] = ...
            CONTACT_ID: typing.ClassVar[str] = ...
            MSG_ID: typing.ClassVar[str] = ...
            TYPE: typing.ClassVar[str] = ...
            @staticmethod
            def getAddrUriForMessage(messageId: str | java.lang.String, /) -> android.net.Uri: ...

    class Carriers(BaseColumns):
        ALWAYS_ON: typing.ClassVar[str] = ...
        APN: typing.ClassVar[str] = ...
        AUTH_TYPE: typing.ClassVar[str] = ...
        BEARER: typing.ClassVar[str] = ...
        CARRIER_ENABLED: typing.ClassVar[str] = ...
        CARRIER_ID: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        CURRENT: typing.ClassVar[str] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        MCC: typing.ClassVar[str] = ...
        MMSC: typing.ClassVar[str] = ...
        MMSPORT: typing.ClassVar[str] = ...
        MMSPROXY: typing.ClassVar[str] = ...
        MNC: typing.ClassVar[str] = ...
        MTU_V4: typing.ClassVar[str] = ...
        MTU_V6: typing.ClassVar[str] = ...
        MVNO_MATCH_DATA: typing.ClassVar[str] = ...
        MVNO_TYPE: typing.ClassVar[str] = ...
        NAME: typing.ClassVar[str] = ...
        NETWORK_TYPE_BITMASK: typing.ClassVar[str] = ...
        NUMERIC: typing.ClassVar[str] = ...
        PASSWORD: typing.ClassVar[str] = ...
        PORT: typing.ClassVar[str] = ...
        PROTOCOL: typing.ClassVar[str] = ...
        PROXY: typing.ClassVar[str] = ...
        ROAMING_PROTOCOL: typing.ClassVar[str] = ...
        SERVER: typing.ClassVar[str] = ...
        SIM_APN_URI: typing.ClassVar[android.net.Uri] = ...
        SUBSCRIPTION_ID: typing.ClassVar[str] = ...
        TYPE: typing.ClassVar[str] = ...
        USER: typing.ClassVar[str] = ...
        USER_EDITABLE: typing.ClassVar[str] = ...
        USER_VISIBLE: typing.ClassVar[str] = ...

    class CarrierId(BaseColumns):
        CARRIER_ID: typing.ClassVar[str] = ...
        CARRIER_NAME: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        SPECIFIC_CARRIER_ID: typing.ClassVar[str] = ...
        SPECIFIC_CARRIER_ID_NAME: typing.ClassVar[str] = ...
        @staticmethod
        def getSpecificCarrierIdUriForSubscriptionId(subscriptionId: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...
        @staticmethod
        def getUriForSubscriptionId(subscriptionId: int | java.jint | java.lang.Integer, /) -> android.net.Uri: ...

    class CanonicalAddressesColumns(BaseColumns):
        ADDRESS: typing.ClassVar[str] = ...

    class BaseMmsColumns(BaseColumns):
        CONTENT_CLASS: typing.ClassVar[str] = ...
        CONTENT_LOCATION: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CREATOR: typing.ClassVar[str] = ...
        DATE: typing.ClassVar[str] = ...
        DATE_SENT: typing.ClassVar[str] = ...
        DELIVERY_REPORT: typing.ClassVar[str] = ...
        DELIVERY_TIME: typing.ClassVar[str] = ...
        EXPIRY: typing.ClassVar[str] = ...
        LOCKED: typing.ClassVar[str] = ...
        MESSAGE_BOX: typing.ClassVar[str] = ...
        MESSAGE_BOX_ALL: typing.ClassVar[int] = ...
        MESSAGE_BOX_DRAFTS: typing.ClassVar[int] = ...
        MESSAGE_BOX_FAILED: typing.ClassVar[int] = ...
        MESSAGE_BOX_INBOX: typing.ClassVar[int] = ...
        MESSAGE_BOX_OUTBOX: typing.ClassVar[int] = ...
        MESSAGE_BOX_SENT: typing.ClassVar[int] = ...
        MESSAGE_CLASS: typing.ClassVar[str] = ...
        MESSAGE_ID: typing.ClassVar[str] = ...
        MESSAGE_SIZE: typing.ClassVar[str] = ...
        MESSAGE_TYPE: typing.ClassVar[str] = ...
        MMS_VERSION: typing.ClassVar[str] = ...
        PRIORITY: typing.ClassVar[str] = ...
        READ: typing.ClassVar[str] = ...
        READ_REPORT: typing.ClassVar[str] = ...
        READ_STATUS: typing.ClassVar[str] = ...
        REPORT_ALLOWED: typing.ClassVar[str] = ...
        RESPONSE_STATUS: typing.ClassVar[str] = ...
        RESPONSE_TEXT: typing.ClassVar[str] = ...
        RETRIEVE_STATUS: typing.ClassVar[str] = ...
        RETRIEVE_TEXT: typing.ClassVar[str] = ...
        RETRIEVE_TEXT_CHARSET: typing.ClassVar[str] = ...
        SEEN: typing.ClassVar[str] = ...
        STATUS: typing.ClassVar[str] = ...
        SUBJECT: typing.ClassVar[str] = ...
        SUBJECT_CHARSET: typing.ClassVar[str] = ...
        SUBSCRIPTION_ID: typing.ClassVar[str] = ...
        TEXT_ONLY: typing.ClassVar[str] = ...
        THREAD_ID: typing.ClassVar[str] = ...
        TRANSACTION_ID: typing.ClassVar[str] = ...

class UserDictionary(java.lang.Object):
    AUTHORITY: typing.ClassVar[str] = ...
    CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
    def __init__(self) -> None: ...

    class Words(BaseColumns):
        APP_ID: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DEFAULT_SORT_ORDER: typing.ClassVar[str] = ...
        FREQUENCY: typing.ClassVar[str] = ...
        LOCALE: typing.ClassVar[str] = ...
        LOCALE_TYPE_ALL: typing.ClassVar[int] = ...
        LOCALE_TYPE_CURRENT: typing.ClassVar[int] = ...
        SHORTCUT: typing.ClassVar[str] = ...
        WORD: typing.ClassVar[str] = ...
        _ID: typing.ClassVar[str] = ...
        def __init__(self) -> None: ...
        @typing.overload
        @staticmethod
        def addWord(context: android.content.Context, word: str | java.lang.String, frequency: int | java.jint | java.lang.Integer, localeType: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        @staticmethod
        def addWord(context: android.content.Context, word: str | java.lang.String, frequency: int | java.jint | java.lang.Integer, shortcut: str | java.lang.String, locale: java.util.Locale, /) -> None: ...

class VoicemailContract(java.lang.Object):
    ACTION_FETCH_VOICEMAIL: typing.ClassVar[str] = ...
    ACTION_NEW_VOICEMAIL: typing.ClassVar[str] = ...
    ACTION_SYNC_VOICEMAIL: typing.ClassVar[str] = ...
    AUTHORITY: typing.ClassVar[str] = ...
    EXTRA_PHONE_ACCOUNT_HANDLE: typing.ClassVar[str] = ...
    EXTRA_SELF_CHANGE: typing.ClassVar[str] = ...
    PARAM_KEY_SOURCE_PACKAGE: typing.ClassVar[str] = ...

    class Voicemails(BaseColumns, OpenableColumns):
        ARCHIVED: typing.ClassVar[str] = ...
        BACKED_UP: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATE: typing.ClassVar[str] = ...
        DELETED: typing.ClassVar[str] = ...
        DIRTY: typing.ClassVar[str] = ...
        DIRTY_RETAIN: typing.ClassVar[int] = ...
        DIR_TYPE: typing.ClassVar[str] = ...
        DURATION: typing.ClassVar[str] = ...
        HAS_CONTENT: typing.ClassVar[str] = ...
        IS_OMTP_VOICEMAIL: typing.ClassVar[str] = ...
        IS_READ: typing.ClassVar[str] = ...
        ITEM_TYPE: typing.ClassVar[str] = ...
        LAST_MODIFIED: typing.ClassVar[str] = ...
        MIME_TYPE: typing.ClassVar[str] = ...
        NEW: typing.ClassVar[str] = ...
        NUMBER: typing.ClassVar[str] = ...
        PHONE_ACCOUNT_COMPONENT_NAME: typing.ClassVar[str] = ...
        PHONE_ACCOUNT_ID: typing.ClassVar[str] = ...
        RESTORED: typing.ClassVar[str] = ...
        SOURCE_DATA: typing.ClassVar[str] = ...
        SOURCE_PACKAGE: typing.ClassVar[str] = ...
        TRANSCRIPTION: typing.ClassVar[str] = ...
        @staticmethod
        def buildSourceUri(packageName: str | java.lang.String, /) -> android.net.Uri: ...

    class Status(BaseColumns):
        CONFIGURATION_STATE: typing.ClassVar[str] = ...
        CONFIGURATION_STATE_CAN_BE_CONFIGURED: typing.ClassVar[int] = ...
        CONFIGURATION_STATE_CONFIGURING: typing.ClassVar[int] = ...
        CONFIGURATION_STATE_DISABLED: typing.ClassVar[int] = ...
        CONFIGURATION_STATE_FAILED: typing.ClassVar[int] = ...
        CONFIGURATION_STATE_NOT_CONFIGURED: typing.ClassVar[int] = ...
        CONFIGURATION_STATE_OK: typing.ClassVar[int] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        DATA_CHANNEL_STATE: typing.ClassVar[str] = ...
        DATA_CHANNEL_STATE_BAD_CONFIGURATION: typing.ClassVar[int] = ...
        DATA_CHANNEL_STATE_COMMUNICATION_ERROR: typing.ClassVar[int] = ...
        DATA_CHANNEL_STATE_NO_CONNECTION: typing.ClassVar[int] = ...
        DATA_CHANNEL_STATE_NO_CONNECTION_CELLULAR_REQUIRED: typing.ClassVar[int] = ...
        DATA_CHANNEL_STATE_OK: typing.ClassVar[int] = ...
        DATA_CHANNEL_STATE_SERVER_CONNECTION_ERROR: typing.ClassVar[int] = ...
        DATA_CHANNEL_STATE_SERVER_ERROR: typing.ClassVar[int] = ...
        DIR_TYPE: typing.ClassVar[str] = ...
        ITEM_TYPE: typing.ClassVar[str] = ...
        NOTIFICATION_CHANNEL_STATE: typing.ClassVar[str] = ...
        NOTIFICATION_CHANNEL_STATE_MESSAGE_WAITING: typing.ClassVar[int] = ...
        NOTIFICATION_CHANNEL_STATE_NO_CONNECTION: typing.ClassVar[int] = ...
        NOTIFICATION_CHANNEL_STATE_OK: typing.ClassVar[int] = ...
        PHONE_ACCOUNT_COMPONENT_NAME: typing.ClassVar[str] = ...
        PHONE_ACCOUNT_ID: typing.ClassVar[str] = ...
        QUOTA_OCCUPIED: typing.ClassVar[str] = ...
        QUOTA_TOTAL: typing.ClassVar[str] = ...
        QUOTA_UNAVAILABLE: typing.ClassVar[int] = ...
        SETTINGS_URI: typing.ClassVar[str] = ...
        SOURCE_PACKAGE: typing.ClassVar[str] = ...
        SOURCE_TYPE: typing.ClassVar[str] = ...
        VOICEMAIL_ACCESS_URI: typing.ClassVar[str] = ...
        @staticmethod
        def buildSourceUri(packageName: str | java.lang.String, /) -> android.net.Uri: ...
